@@ -110,19 +110,23 @@ class CRMEntity
 			$idname='notesid';      $tablename='notes';     $descname='notecontent';
 		}
 
-		$sql="update ".$tablename." set filename='".$filename."' where ".$idname."=".$id;
-		$adb->query($sql);
+		$sql="update $tablename set filename=? where $idname=?";
+		$params = array($filename, $id);
+		$adb->pquery($sql, $params);
 
-		$sql1 = "insert into vtiger_crmentity (crmid,smcreatorid,smownerid,setype,description,createdtime,modifiedtime) values(".$current_id.",".$current_user->id.",".$ownerid.",'".$module." Attachment','"."',".$adb->formatString("vtiger_crmentity","createdtime",$date_var).",".$adb->formatString("vtiger_crmentity","modifiedtime",$date_var).")";
-		$adb->query($sql1);
+		$sql1 = "insert into vtiger_crmentity (crmid,smcreatorid,smownerid,setype,description,createdtime,modifiedtime) values(?, ?, ?, ?, ?, ?, ?)";
+		$params1 = array($current_id, $current_user->id, $ownerid, $module." Attachment", '', $adb->formatDate($date_var, true), $adb->formatDate($date_var, true));
+		$adb->pquery($sql1, $params1);
 
-		$sql2="insert into vtiger_attachments(attachmentsid, name, description, type) values(".$current_id.",'".$filename."','"."','".$filetype."')";
-		$result=$adb->query($sql2);
+		$sql2="insert into vtiger_attachments(attachmentsid, name, description, type) values(?, ?, ?, ?)";
+		$params2 = array($current_id, $filename, '', $filetype);
+		$result=$adb->pquery($sql2, $params2);
 
 		//TODO -- instead of put contents in db now we should store the file in harddisk
 
-		$sql3='insert into vtiger_seattachmentsrel values('.$id.','.$current_id.')';
-		$adb->query($sql3);
+		$sql3='insert into vtiger_seattachmentsrel values(?, ?)';
+		$params3 = array($id, $current_id);
+		$adb->pquery($sql3, $params3);
 	}
 	
 
@@ -149,9 +153,14 @@ class CRMEntity
 		if(!isset($ownerid) || $ownerid=='')
 			$ownerid = $current_user->id;
 
-	
+		if(isset($file_details['original_name']) && $file_details['original_name'] != null) {
+			$file_name = $file_details['original_name'];
+		} else {
+			$file_name = $file_details['name'];
+		}
+
 		// Arbitrary File Upload Vulnerability fix - Philip
-		$binFile = preg_replace('/\s+/', '_', $file_details['name']);//replace space with _ in filename
+		$binFile = preg_replace('/\s+/', '_', $file_name);//replace space with _ in filename
 		$ext_pos = strrpos($binFile, ".");
 
 		$ext = substr($binFile, $ext_pos + 1);
@@ -164,7 +173,7 @@ class CRMEntity
 
 		$current_id = $adb->getUniqueID("vtiger_crmentity");
 
-		$filename = basename($binFile);
+		$filename = ltrim(basename(" ".$binFile)); //allowed filename like UTF-8 characters 
 		$filetype= $file_details['type'];
 		$filesize = $file_details['size'];
 		$filetmp_name = $file_details['tmp_name'];
@@ -187,31 +196,66 @@ class CRMEntity
 			//This is only to update the attached filename in the vtiger_notes vtiger_table for the Notes module
 			if($module=='Notes')
 			{
-				$sql="update vtiger_notes set filename='".$filename."' where notesid = ".$id;
-				$adb->query($sql);
+				$sql="update vtiger_notes set filename=? where notesid = ?";
+				$params = array($filename, $id); 
+				$adb->pquery($sql, $params);
 			}
+			if($module == 'Contacts' || $module == 'Products')
+			{
+				$sql1 = "insert into vtiger_crmentity (crmid,smcreatorid,smownerid,setype,description,createdtime,modifiedtime) values(?, ?, ?, ?, ?, ?, ?)";
+				$params1 = array($current_id, $current_user->id, $ownerid, $module." Image", $this->column_fields['description'], $adb->formatDate($date_var, true), $adb->formatDate($date_var, true));		
+			}
+			else
+			{
+				$sql1 = "insert into vtiger_crmentity (crmid,smcreatorid,smownerid,setype,description,createdtime,modifiedtime) values(?, ?, ?, ?, ?, ?, ?)";
+				$params1 = array($current_id, $current_user->id, $ownerid, $module." Attachment", $this->column_fields['description'], $adb->formatDate($date_var, true), $adb->formatDate($date_var, true));		
+			}
+			$adb->pquery($sql1, $params1);
 
-			$sql1 = "insert into vtiger_crmentity (crmid,smcreatorid,smownerid,setype,description,createdtime,modifiedtime) values(".$current_id.",".$current_user->id.",".$ownerid.",'".$module." Attachment','".$this->column_fields['description']."',".$adb->formatString("vtiger_crmentity","createdtime",$date_var).",".$adb->formatString("vtiger_crmentity","modifiedtime",$date_var).")";
-			$adb->query($sql1);
-
-			$sql2="insert into vtiger_attachments(attachmentsid, name, description, type, path) values(".$current_id.",'".$filename."','".$this->column_fields['description']."','".$filetype."','".$upload_file_path."')";
-			$result=$adb->query($sql2);
+			$sql2="insert into vtiger_attachments(attachmentsid, name, description, type, path) values(?, ?, ?, ?, ?)";
+			$params2 = array($current_id, $filename, $this->column_fields['description'], $filetype, $upload_file_path);
+			$result=$adb->pquery($sql2, $params2);
 
 			if($_REQUEST['mode'] == 'edit')
 			{
 				if($id != '' && $_REQUEST['fileid'] != '')
 				{
-					$delquery = 'delete from vtiger_seattachmentsrel where crmid = '.$id.' and attachmentsid = '.$_REQUEST['fileid'];
-					$adb->query($delquery);
+					$delquery = 'delete from vtiger_seattachmentsrel where crmid = ? and attachmentsid = ?';
+					$delparams = array($id, $_REQUEST['fileid']);
+					$adb->pquery($delquery, $delparams);
 				}
 			}
 			if($module == 'Notes')
 			{
-				$query = "delete from vtiger_seattachmentsrel where crmid = ".$id;
-				$adb->query($query);
+				$query = "delete from vtiger_seattachmentsrel where crmid = ?";
+				$qparams = array($id);
+				$adb->pquery($query, $qparams);
+			}
+			if($module == 'Contacts')
+			{
+				$att_sql="select vtiger_seattachmentsrel.attachmentsid  from vtiger_seattachmentsrel inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_seattachmentsrel.attachmentsid where vtiger_crmentity.setype='Contacts Image' and vtiger_seattachmentsrel.crmid=?";
+				$res=$adb->pquery($att_sql, array($id));
+				$attachmentsid= $adb->query_result($res,0,'attachmentsid');
+				if($attachmentsid !='' )
+				{
+					$delquery='delete from vtiger_seattachmentsrel where crmid=? && attachmentsid=?';
+					$adb->pquery($delquery, array($id, $attachmentsid));
+					$crm_delquery="delete from vtiger_crmentity where crmid=?";
+					$adb->pquery($crm_delquery, array($attachmentsid));
+					$sql5='insert into vtiger_seattachmentsrel values(?,?)';
+					$adb->pquery($sql5, array($id, $current_id));
+				}
+				else
+				{
+					$sql3='insert into vtiger_seattachmentsrel values(?,?)';
+					$adb->pquery($sql3, array($id, $current_id));
+				}
+			}
+			else
+			{
+				$sql3='insert into vtiger_seattachmentsrel values(?,?)';
+				$adb->pquery($sql3, array($id, $current_id));
 			}
-			$sql3='insert into vtiger_seattachmentsrel values('.$id.','.$current_id.')';
-			$adb->query($sql3);
 
 			return true;
 		}
@@ -242,8 +286,8 @@ class CRMEntity
 		$ownerid = $this->column_fields['assigned_user_id'];
 	}
         
-	$sql="select ownedby from vtiger_tab where name='".$module."'";
-	$res=$adb->query($sql);
+	$sql="select ownedby from vtiger_tab where name=?";
+	$res=$adb->pquery($sql, array($module));
 	$this->ownedby = $adb->query_result($res,0,'ownedby');
 	
 	if($this->ownedby == 1)
@@ -259,19 +303,20 @@ class CRMEntity
 	}
 	if($this->mode == 'edit')
 	{
-		$description_val = from_html($adb->formatString("vtiger_crmentity","description",$this->column_fields['description']),($insertion_mode == 'edit')?true:false);
+		$description_val = from_html($this->column_fields['description'],($insertion_mode == 'edit')?true:false);
 
 		require('user_privileges/user_privileges_'.$current_user->id.'.php');
 		$tabid = getTabid($module);
 		if($is_admin == true || $profileGlobalPermission[1] == 0 || $profileGlobalPermission[2] ==0)
 		{
-			$sql = "update vtiger_crmentity set smownerid=".$ownerid.",modifiedby=".$current_user->id.",description=".$description_val.", modifiedtime=".$adb->formatString("vtiger_crmentity","modifiedtime",$date_var)." where crmid=".$this->id;
+			$sql = "update vtiger_crmentity set smownerid=?,modifiedby=?,description=?, modifiedtime=? where crmid=?";
+			$params = array($ownerid, $current_user->id, $description_val, $adb->formatDate($date_var, true), $this->id);	
 		}
 		else
 		{
 			$profileList = getCurrentUserProfileList();
-			$perm_qry = "SELECT columnname FROM vtiger_field INNER JOIN vtiger_profile2field ON vtiger_profile2field.fieldid = vtiger_field.fieldid INNER JOIN vtiger_def_org_field ON vtiger_def_org_field.fieldid = vtiger_field.fieldid WHERE vtiger_field.tabid = ".$tabid." AND vtiger_profile2field.visible = 0 AND vtiger_profile2field.profileid IN ".$profileList." AND vtiger_def_org_field.visible = 0 and vtiger_field.tablename='vtiger_crmentity' and vtiger_field.displaytype in (1,3);";
-			$perm_result = $adb->query($perm_qry);
+			$perm_qry = "SELECT columnname FROM vtiger_field INNER JOIN vtiger_profile2field ON vtiger_profile2field.fieldid = vtiger_field.fieldid INNER JOIN vtiger_def_org_field ON vtiger_def_org_field.fieldid = vtiger_field.fieldid WHERE vtiger_field.tabid = ? AND vtiger_profile2field.visible = 0 AND vtiger_profile2field.profileid IN (". generateQuestionMarks($profileList) . ") AND vtiger_def_org_field.visible = 0 and vtiger_field.tablename='vtiger_crmentity' and vtiger_field.displaytype in (1,3);";
+			$perm_result = $adb->pquery($perm_qry, array($tabid, $profileList));
 			$perm_rows = $adb->num_rows($perm_result);
 			for($i=0; $i<$perm_rows; $i++)
 			{
@@ -279,44 +324,42 @@ class CRMEntity
 			}
 			if(is_array($columname) && in_array("description",$columname))
 			{
-				$sql = "update vtiger_crmentity set smownerid=".$ownerid.",modifiedby=".$current_user->id.",description=".$description_val.", modifiedtime=".$adb->formatString("vtiger_crmentity","modifiedtime",$date_var)." where crmid=".$this->id;
+				$sql = "update vtiger_crmentity set smownerid=?,modifiedby=?,description=?, modifiedtime=? where crmid=?";
+				$params = array($ownerid, $current_user->id, $description_val, $adb->formatDate($date_var, true), $this->id);
 			}
 			else
 			{
-				$sql = "update vtiger_crmentity set smownerid=".$ownerid.",modifiedby=".$current_user->id.", modifiedtime=".$adb->formatString("vtiger_crmentity","modifiedtime",$date_var)." where crmid=".$this->id;
+				$sql = "update vtiger_crmentity set smownerid=?,modifiedby=?, modifiedtime=? where crmid=?";
+				$params = array($ownerid, $current_user->id, $adb->formatDate($date_var, true), $this->id);		
 			}
 		}
-		$adb->query($sql);
-		$sql1 ="delete from vtiger_ownernotify where crmid=".$this->id;
-		$adb->query($sql1);
+		$adb->pquery($sql, $params);
+		$sql1 ="delete from vtiger_ownernotify where crmid=?";
+		$params1 = array($this->id);
+		$adb->pquery($sql1, $params1);
 		if($ownerid != $current_user->id)
 		{
-			$sql1 = "insert into vtiger_ownernotify values(".$this->id.",".$ownerid.",null)";
-			$adb->query($sql1);
-		}
-		
-		
-
-		
-
-		
+			$sql1 = "insert into vtiger_ownernotify values(?,?,?)";
+			$params1 = array($this->id, $ownerid, null);
+			$adb->pquery($sql1, $params1);
+		}		
 	}
 	else
 	{
 		//if this is the create mode and the group allocation is chosen, then do the following
 		$current_id = $adb->getUniqueID("vtiger_crmentity");
 		$_REQUEST['currentid']=$current_id;
+		if($current_user->id == '')
+			$current_user->id = 0;
 
-		$description_val = from_html($adb->formatString("vtiger_crmentity","description",$this->column_fields['description']),($insertion_mode == 'edit')?true:false);
-		$sql = "insert into vtiger_crmentity (crmid,smcreatorid,smownerid,setype,description,createdtime,modifiedtime) values('".$current_id."','".$current_user->id."','".$ownerid."','".$module."',".$description_val.",".$adb->formatDate($date_var).",".$adb->formatDate($date_var).")";
-		$adb->query($sql);
+		$description_val = from_html($this->column_fields['description'],($insertion_mode == 'edit')?true:false);
+		$sql = "insert into vtiger_crmentity (crmid,smcreatorid,smownerid,setype,description,createdtime,modifiedtime) values(?,?,?,?,?,?,?)";
+		$params = array($current_id, $current_user->id, $ownerid, $module, $description_val, $adb->formatDate($date_var, true), $adb->formatDate($date_var, true));
+		$adb->pquery($sql, $params);
 		$this->id = $current_id;
 	}
 
-	
-
-
-    }
+   }
 
 
 	/** Function to insert values in the specifed table for the specified module
@@ -326,7 +369,7 @@ class CRMEntity
   function insertIntoEntityTable($table_name, $module)
   {
 	  global $log;
-  	  global $current_user;	  
+  	  global $current_user,$app_strings;
 	   $log->info("function insertIntoEntityTable ".$module.' vtiger_table name ' .$table_name);
 	  global $adb;
 	  $insertion_mode = $this->mode;
@@ -334,8 +377,8 @@ class CRMEntity
 	  //Checkin whether an entry is already is present in the vtiger_table to update
 	  if($insertion_mode == 'edit')
 	  {
-		  $check_query = "select * from ".$table_name." where ".$this->tab_name_index[$table_name]."=".$this->id;
-		  $check_result=$adb->query($check_query);
+		  $check_query = "select * from $table_name where ". $this->tab_name_index[$table_name] ."=?";
+		  $check_result=$adb->pquery($check_query, array($this->id));
 
 		  $num_rows = $adb->num_rows($check_result);
 
@@ -348,28 +391,47 @@ class CRMEntity
 	  if($insertion_mode == 'edit')
 	  {
 		  $update = '';
+		  $update_params = array();
 		  $tabid= getTabid($module);
 	  	  if($tabid == 9)
-	          	$tabid ="9,16";	  
+	          	$tabid = array(9,16);	  
 		  require('user_privileges/user_privileges_'.$current_user->id.'.php');
 		  if($is_admin == true || $profileGlobalPermission[1] == 0 || $profileGlobalPermission[2] ==0)
 		  {
 
-			  $sql = "select * from vtiger_field where tabid in (".$tabid.") and tablename='".$table_name."' and displaytype in (1,3) group by columnname"; 
+			 	$sql = "select * from vtiger_field where tabid in (". generateQuestionMarks($tabid) .") and tablename=? and displaytype in (1,3) group by columnname"; 
+				$params = array($tabid, $table_name);	
 		  }
 		  else
 		  {
 			  $profileList = getCurrentUserProfileList();
-			  $sql = "SELECT *
-			  FROM vtiger_field
-			  INNER JOIN vtiger_profile2field
-			  ON vtiger_profile2field.fieldid = vtiger_field.fieldid
-			  INNER JOIN vtiger_def_org_field
-			  ON vtiger_def_org_field.fieldid = vtiger_field.fieldid
-			  WHERE vtiger_field.tabid in (".$tabid.")
-			  AND vtiger_profile2field.visible = 0 
-			  AND vtiger_profile2field.profileid IN ".$profileList."
-			  AND vtiger_def_org_field.visible = 0 and vtiger_field.tablename='".$table_name."' and vtiger_field.displaytype in (1,3) group by columnname";
+			  
+			  if (count($profileList) > 0) {
+			  	$sql = "SELECT *
+			  			FROM vtiger_field
+			  			INNER JOIN vtiger_profile2field
+			  			ON vtiger_profile2field.fieldid = vtiger_field.fieldid
+			  			INNER JOIN vtiger_def_org_field
+			  			ON vtiger_def_org_field.fieldid = vtiger_field.fieldid
+			  			WHERE vtiger_field.tabid in (". generateQuestionMarks($tabid) .")
+			  			AND vtiger_profile2field.visible = 0 
+			  			AND vtiger_profile2field.profileid IN (". generateQuestionMarks($profileList) .")
+			  			AND vtiger_def_org_field.visible = 0 and vtiger_field.tablename=? and vtiger_field.displaytype in (1,3) group by columnname";
+			  			  
+			  	$params = array($tabid, $profileList, $table_name);
+			  } else {
+			  	$sql = "SELECT *
+			  			FROM vtiger_field
+			  			INNER JOIN vtiger_profile2field
+			  			ON vtiger_profile2field.fieldid = vtiger_field.fieldid
+			  			INNER JOIN vtiger_def_org_field
+			  			ON vtiger_def_org_field.fieldid = vtiger_field.fieldid
+			  			WHERE vtiger_field.tabid in (". generateQuestionMarks($tabid) .")
+			  			AND vtiger_profile2field.visible = 0 
+			  			AND vtiger_def_org_field.visible = 0 and vtiger_field.tablename=? and vtiger_field.displaytype in (1,3) group by columnname";
+			  	
+				$params = array($tabid, $table_name);
+			  }
 		  }	   
 
 	  }
@@ -381,18 +443,20 @@ class CRMEntity
 		 	$currentuser_id = $adb->getUniqueID("vtiger_users");
 			$this->id = $currentuser_id;
 		  }
-		  $value = $this->id;
+		  $value = array($this->id);
 	  	  $tabid= getTabid($module);	
-		  $sql = "select * from vtiger_field where tabid=".$tabid." and tablename='".$table_name."' and displaytype in (1,3,4)"; 
+		  $sql = "select * from vtiger_field where tabid=? and tablename=? and displaytype in (1,3,4)"; 
+		  $params = array($tabid, $table_name);
 	  }
 
-	  $result = $adb->query($sql);
+	  $result = $adb->pquery($sql, $params);
 	  $noofrows = $adb->num_rows($result);
 	  for($i=0; $i<$noofrows; $i++)
 	  {
 		  $fieldname=$adb->query_result($result,$i,"fieldname");
 		  $columname=$adb->query_result($result,$i,"columnname");
 		  $uitype=$adb->query_result($result,$i,"uitype");
+
 		  if(isset($this->column_fields[$fieldname]))
 		  {
 			  if($uitype == 56)
@@ -407,6 +471,23 @@ class CRMEntity
 				  }
 
 			  }
+			  elseif($uitype == 15 || $uitype == 16 || $uitype == 111)
+			  {
+
+				  if($this->column_fields[$fieldname] == $app_strings['LBL_NOT_ACCESSIBLE'])
+				  {
+					 
+					//If the value in the request is Not Accessible for a picklist, the existing value will be replaced instead of Not Accessible value.
+					 $sql="select $columname from  $table_name where ".$this->tab_name_index[$table_name]."=?";
+					 $res = $adb->pquery($sql,array($this->id));
+					 $pick_val = $adb->query_result($res,0,$columname);
+					 $fldvalue = $pick_val;
+				  }
+				  else
+				  {
+					  $fldvalue = $this->column_fields[$fieldname];
+				   }
+			  }
 			  elseif($uitype == 33)
 			  {
   				if(is_array($this->column_fields[$fieldname]))
@@ -439,9 +520,9 @@ class CRMEntity
 			  else
 			  {
 				  $fldvalue = $this->column_fields[$fieldname]; 
-				  $fldvalue = stripslashes($fldvalue);
 			  }
-			  $fldvalue = from_html($adb->formatString($table_name,$columname,$fldvalue),($insertion_mode == 'edit')?true:false);
+			  if($uitype != 33)
+				  $fldvalue = from_html($fldvalue,($insertion_mode == 'edit')?true:false);
 
 
 
@@ -450,7 +531,12 @@ class CRMEntity
 		  {
 			  $fldvalue = '';
 		  }
-		  if($fldvalue=='') $fldvalue ="NULL";
+		  if($fldvalue=='') {
+		  	$fldvalue = $this->get_column_value($columname, $fldvalue, $fieldname, $uitype);
+			//$fldvalue =null;
+		  }
+		  /*else
+			$fldvalue = htmlentities($fldvalue);*/	
 		  if($insertion_mode == 'edit')
 		  {
 			  if($table_name == 'vtiger_notes' && $columname == 'filename' && $_FILES['filename']['name'] == '')
@@ -461,18 +547,19 @@ class CRMEntity
 			  {
 				  if($i == 0)
 				  {
-					  $update = $columname."=".$fldvalue."";
+					  $update = $columname."=?";
 				  }
 				  else
 				  {
-					  $update .= ', '.$columname."=".$fldvalue."";
+					  $update .= ', '.$columname."=?";
 				  }
+				  array_push($update_params, $fldvalue);
 			  }
 		  }
 		  else
 		  {
 			  $column .= ", ".$columname;
-			  $value .= ", ".$fldvalue."";
+			  array_push($value, $fldvalue);
 		  }
 
 	  }
@@ -485,14 +572,15 @@ class CRMEntity
 	  {
 		  if($_REQUEST['module'] == 'Potentials')
 		  {
-			  $dbquery = 'select sales_stage from vtiger_potential where potentialid = '.$this->id;
-			  $sales_stage = $adb->query_result($adb->query($dbquery),0,'sales_stage');
+			  $dbquery = 'select sales_stage from vtiger_potential where potentialid = ?';
+			  $sales_stage = $adb->query_result($adb->pquery($dbquery, array($this->id)),0,'sales_stage');
 			  if($sales_stage != $_REQUEST['sales_stage'] && $_REQUEST['sales_stage'] != '')
 			  {
 				  $date_var = date('YmdHis');
-				  $closingdate = getDBInsertDateValue($this->column_fields['closingdate']);
-				  $sql = "insert into vtiger_potstagehistory values('',".$this->id.",'".$this->column_fields['amount']."','".$sales_stage."','".$this->column_fields['probability']."',0,".$adb->formatString("vtiger_potstagehistory","closedate",$closingdate).",".$adb->formatString("vtiger_potstagehistory","lastmodified",$date_var).")";
-				  $adb->query($sql);
+				  $closingdate = ($_REQUEST['ajxaction'] == 'DETAILVIEW')? $this->column_fields['closingdate'] : getDBInsertDateValue($this->column_fields['closingdate']);
+				  $sql = "insert into vtiger_potstagehistory values(?,?,?,?,?,?,?,?)";
+				  $params = array('', $this->id, $this->column_fields['amount'], decode_html($sales_stage), $this->column_fields['probability'], 0, $adb->formatDate($closingdate, true), $adb->formatDate($date_var, true));
+				  $adb->pquery($sql, $params);
 			  }
 		  }
 		  elseif($_REQUEST['module'] == 'PurchaseOrder' || $_REQUEST['module'] == 'SalesOrder' || $_REQUEST['module'] == 'Quotes' || $_REQUEST['module'] == 'Invoice')
@@ -526,29 +614,39 @@ class CRMEntity
 				$total = $_REQUEST['total'];
 			  }
 
+				if($this->column_fields["$history_field_array[$inventory_module]"] == $app_strings['LBL_NOT_ACCESSIBLE'])
+				  {
+					 
+					  //If the value in the request is Not Accessible for a picklist, the existing value will be replaced instead of Not Accessible value.
+					  $his_col = $history_field_array[$inventory_module];
+					  $his_sql="select $his_col from  $this->table_name where ".$this->module_id."=?";
+					 $his_res = $adb->pquery($his_sql,array($this->id));
+					  $status_value = $adb->query_result($his_res,0,$his_col);
+					 $stat_value = $status_value;
+				  }
+				  else
+				  {
+					  $stat_value  = $this->column_fields["$history_field_array[$inventory_module]"];
+				  }
 			  $oldvalue = getSingleFieldValue($this->table_name,$history_field_array[$inventory_module],$this->module_id,$this->id);
-			  if($oldvalue != $this->column_fields["$history_field_array[$inventory_module]"])
+			  if($this->column_fields["$history_field_array[$inventory_module]"]!= '' &&  $oldvalue != $stat_value )
 			  {
-				  addInventoryHistory($inventory_module, $this->id,$relatedname,$total,$this->column_fields["$history_field_array[$inventory_module]"]);
+				  addInventoryHistory($inventory_module, $this->id,$relatedname,$total,$stat_value);
 			  }
 		  }
-
 		  //Check done by Don. If update is empty the the query fails
 		  if(trim($update) != '')
         	  {
-		  	$sql1 = "update ".$table_name." set ".$update." where ".$this->tab_name_index[$table_name]."=".$this->id;
-
-		  	$adb->query($sql1); 
+		  	$sql1 = "update $table_name set $update where ". $this->tab_name_index[$table_name] ."=?";
+			array_push($update_params, $this->id);
+		  	$adb->pquery($sql1, $update_params); 
 		  }
 		  
-
 	  }
 	  else
 	  {
-		  $sql1 = "insert into ".$table_name." (".$column.") values(".$value.")";
-		  $adb->query($sql1); 
-		  
-
+	  	  $sql1 = "insert into $table_name($column) values(". generateQuestionMarks($value) .")";
+		  $adb->pquery($sql1, $value); 
 	  }
 
   }
@@ -572,7 +670,7 @@ function whomToSendMail($module,$insertion_mode,$assigntype)
                elseif($assigntype=='T')
                {
                        $groupname=$_REQUEST['assigned_group_name'];
-                       $resultqry=$adb->query("select groupid from vtiger_groups where groupname='".$groupname."'");
+                       $resultqry=$adb->pquery("select groupid from vtiger_groups where groupname=?", array($groupname));
                        $groupid=$adb->query_result($resultqry,0,"groupid");
                        sendNotificationToGroups($groupid,$this->id,$module);
                }
@@ -587,14 +685,14 @@ function whomToSendMail($module,$insertion_mode,$assigntype)
 function deleteRelation($table_name)
 {
          global $adb;
-         $check_query = "select * from ".$table_name." where ".$this->tab_name_index[$table_name]."=".$this->id;
-         $check_result=$adb->query($check_query);
+         $check_query = "select * from $table_name where ". $this->tab_name_index[$table_name] ."=?";
+         $check_result=$adb->pquery($check_query, array($this->id));
          $num_rows = $adb->num_rows($check_result);
 
          if($num_rows == 1)
          {
-                $del_query = "DELETE from ".$table_name." where ".$this->tab_name_index[$table_name]."=".$this->id;
-                $adb->query($del_query);
+                $del_query = "DELETE from $table_name where ". $this->tab_name_index[$table_name] ."=?";
+                $adb->pquery($del_query, array($this->id));
          }
 
 }
@@ -608,17 +706,17 @@ function getOldFileName($notesid)
 	   global $log;
 $log->info("in getOldFileName  ".$notesid);
 	global $adb;
-	$query1 = "select * from vtiger_seattachmentsrel where crmid=".$notesid;
-	$result = $adb->query($query1);
+	$query1 = "select * from vtiger_seattachmentsrel where crmid=?";
+	$result = $adb->pquery($query1, array($notesid));
 	$noofrows = $adb->num_rows($result);
 	if($noofrows != 0)
 		$attachmentid = $adb->query_result($result,0,'attachmentsid');
 	if($attachmentid != '')
 	{
-		$query2 = "select * from vtiger_attachments where attachmentsid=".$attachmentid;
-		$filename = $adb->query_result($adb->query($query2),0,'name');
+		$query2 = "select * from vtiger_attachments where attachmentsid=?";
+		$filename = $adb->query_result($adb->pquery($query2, array($attachmentid)),0,'name');
 	}
-	return "'".$filename."'";
+	return $filename;
 }
 	
 	
@@ -641,13 +739,21 @@ $log->info("in getOldFileName  ".$notesid);
     $result = Array();
     foreach($this->tab_name_index as $table_name=>$index)
     {
-	    $result[$table_name] = $adb->query("select * from ".$table_name." where ".$index."=".$record);
+	    $result[$table_name] = $adb->pquery("select * from $table_name where $index=?", array($record));
 	    if($adb->query_result($result["vtiger_crmentity"],0,"deleted") == 1)
 	    die("<br><br><center>".$app_strings['LBL_RECORD_DELETE']." <a href='javascript:window.history.back()'>".$app_strings['LBL_GO_BACK'].".</a></center>");
     }
+
+    /* Prasad: Fix for ticket #4595 */
+	if (isset($this->table_name)) {
+    	$mod_index_col = $this->tab_name_index[$this->table_name];
+    	if($adb->query_result($result[$this->table_name],0,$mod_index_col) == '')
+    		die("<br><br><center>".$app_strings['LBL_RECORD_NOT_FOUND'].
+				". <a href='javascript:window.history.back()'>".$app_strings['LBL_GO_BACK'].".</a></center>");
+	}
     $tabid = getTabid($module);
-    $sql1 =  "select * from vtiger_field where tabid=".$tabid;
-    $result1 = $adb->query($sql1);
+    $sql1 =  "select * from vtiger_field where tabid=?";
+    $result1 = $adb->pquery($sql1, array($tabid));
     $noofrows = $adb->num_rows($result1);
     for($i=0; $i<$noofrows; $i++)
     {
@@ -804,8 +910,8 @@ $log->info("in getOldFileName  ".$notesid);
 	*/
 	function mark_deleted($id)
 	{
-		$query = "UPDATE vtiger_crmentity set deleted=1 where crmid='$id'";
-		$this->db->query($query, true,"Error marking record deleted: ");
+		$query = "UPDATE vtiger_crmentity set deleted=1 where crmid=?";
+		$this->db->pquery($query, array($id), true,"Error marking record deleted: ");
 
 
 	}
@@ -858,8 +964,8 @@ $log->info("in getOldFileName  ".$notesid);
          */
         function checkIfCustomTableExists($tablename)
         {
-                $query = "select * from ".$tablename;
-                $result = $this->db->query($query);
+                $query = "select * from ". mysql_real_escape_string($tablename);
+                $result = $this->db->pquery($query, array());
                 $testrow = $this->db->num_fields($result);
                 if($testrow > 1)
                 {
@@ -880,8 +986,8 @@ $log->info("in getOldFileName  ".$notesid);
         {
                 global $adb;
 		$tabid=getTabid($module);		
-                $sql1 = "select columnname,fieldlabel from vtiger_field where generatedtype=2 and tabid=".$tabid;
-                $result = $adb->query($sql1);
+                $sql1 = "select columnname,fieldlabel from vtiger_field where generatedtype=2 and tabid=?";
+                $result = $adb->pquery($sql1, array($tabid));
                 $numRows = $adb->num_rows($result);
                 $sql3 = "select ";
                 for($i=0; $i < $numRows;$i++)
@@ -974,9 +1080,74 @@ $log->info("in getOldFileName  ".$notesid);
 		  
 		}			
 
-	}	
-
+	}
 	
+	/**
+	* Function to get the column value of a field 
+	* @param $columnname -- Column name for the field
+	* @param $fldvalue -- Input value for the field taken from the User
+	* @param $fieldname -- Name of the Field
+	* @param $uitype -- UI type of the field
+	* @return Column value of the field.
+	*/
+	function get_column_value($columname, $fldvalue, $fieldname, $uitype) {
+		if (is_uitype($uitype, "_date_") && $fldvalue == '') {
+			return null;
+		}
+		return $fldvalue;
+	}
+	
+	/**
+	* Function to make change to column fields, depending on the current user's accessibility for the fields
+	*//*
+	function apply_field_security() {
+		global $current_user, $currentModule;
+		
+		require_once('include/utils/UserInfoUtil.php');
+		foreach($this->column_fields as $fieldname=>$fieldvalue) {
+			if (getFieldVisibilityPermission($currentModule, $current_user->id, $fieldname) != '0') {
+				$this->column_fields[$fieldname] = "";
+			}
+		}
+	}*/
+	
+	/**
+	* Function to make change to column fields, depending on the current user's accessibility for the fields
+	*/
+	function apply_field_security() {
+		global $current_user, $currentModule;
+		
+		require_once('include/utils/UserInfoUtil.php');
+		foreach($this->column_fields as $fieldname=>$fieldvalue) {
+		$reset_value = false;
+			if (getFieldVisibilityPermission($currentModule, $current_user->id, $fieldname) != '0') 
+				$reset_value = true;
+			
+			if ($fieldname == "record_id" || $fieldname == "record_module") 
+				$reset_value = false;
 
+			/*
+				if (isset($this->additional_column_fields) && in_array($fieldname, $this->additional_column_fields) == true)
+					$reset_value = false;
+			 */
+			
+			if ($reset_value == true)
+				$this->column_fields[$fieldname] = "";
+		}
+	}
+	
+	/**
+	* Function to initialize the importable fields array, based on the User's accessibility to the fields
+	*/
+	function initImportableFields($module) {		
+		global $current_user;
+		require_once('include/utils/UserInfoUtil.php');
+		
+		$colf = getColumnFields($module);
+		foreach($colf as $key=>$value) {
+			if (getFieldVisibilityPermission($module, $current_user->id, $key) == '0')
+				$this->importable_fields[$key]=1;
+		}
+	}
 }
 ?>
