@@ -57,7 +57,7 @@ function getSearchListHeaderValues($focus, $module,$sort_qry='',$sorder='',$orde
                 }
         }
 	//Added to reduce the no. of queries logging for non-admin vtiger_users -- by Minnie-start
-	$field_list ='(';
+	$field_list = array();
 	$j=0;	
 	require('user_privileges/user_privileges_'.$current_user->id.'.php');
 	foreach($focus->list_fields as $name=>$tableinfo)
@@ -70,49 +70,52 @@ function getSearchListHeaderValues($focus, $module,$sort_qry='',$sorder='',$orde
 				$fieldname = $oCv->list_fields_name[$name];
 			}
 		}
-		if($j != 0)
-		{
-			$field_list .= ', ';
-		}
 		if($fieldname == "accountname" && $module !="Accounts")
 			$fieldname = "account_id";
+
+		if($fieldname == "productname" && $module =="Campaigns")
+			$fieldname = "product_id";
+
 		if($fieldname == "lastname" && $module !="Leads" && $module !="Contacts")
 		{
 			$fieldname = "contact_id";
 		}
-		$field_list .= "'".$fieldname."'";
+		array_push($field_list, $fieldname);
 		$j++;
 	}
-	$field_list .=')';
 	//Getting the Entries from Profile2 vtiger_field vtiger_table
 	if($is_admin == false)
 	{
 		$profileList = getCurrentUserProfileList();
 		//changed to get vtiger_field.fieldname
-		$query  = "SELECT vtiger_profile2field.*,vtiger_field.fieldname FROM vtiger_field INNER JOIN vtiger_profile2field ON vtiger_profile2field.fieldid=vtiger_field.fieldid INNER JOIN vtiger_def_org_field ON vtiger_def_org_field.fieldid=vtiger_field.fieldid WHERE vtiger_field.tabid=".$tabid." AND vtiger_profile2field.visible=0 AND vtiger_def_org_field.visible=0 AND vtiger_profile2field.profileid IN ".$profileList." AND vtiger_field.fieldname IN ".$field_list." GROUP BY vtiger_field.fieldid";
+		$query  = "SELECT vtiger_profile2field.*,vtiger_field.fieldname FROM vtiger_field INNER JOIN vtiger_profile2field ON vtiger_profile2field.fieldid=vtiger_field.fieldid INNER JOIN vtiger_def_org_field ON vtiger_def_org_field.fieldid=vtiger_field.fieldid WHERE vtiger_field.tabid=? AND vtiger_profile2field.visible=0 AND vtiger_def_org_field.visible=0 AND vtiger_profile2field.profileid IN (". generateQuestionMarks($profileList) .") AND vtiger_field.fieldname IN (". generateQuestionMarks($field_list) .") GROUP BY vtiger_field.fieldid";
  		if( $adb->dbType == "pgsql")
  		    $query = fixPostgresQuery( $query, $log, 0);
-		$result = $adb->query($query);
+		$result = $adb->pquery($query, array($tabid, $profileList, $field_list));
 		$field=Array();
 		for($k=0;$k < $adb->num_rows($result);$k++)
 		{
 			$field[]=$adb->query_result($result,$k,"fieldname");
 		}
+
+		//if this field array is empty and the user don't have any one of the admin, view all, edit all permissions then the search picklist options will be empty and we cannot navigate the users list - js error will thrown in function getListViewEntries_js in Smarty\templates\Popup.tpl
+		if($module == 'Users' && empty($field))
+			$field = Array("last_name","email1");
 	}
 
         //modified for vtiger_customview 27/5 - $app_strings change to $mod_strings
         foreach($focus->list_fields as $name=>$tableinfo)
         {
-                //$fieldname = $focus->list_fields_name[$name];  //commented for vtiger_customview 27/5
                 //added for vtiger_customview 27/5
                 if($oCv)
                 {
                         if(isset($oCv->list_fields_name))
-                        {
+			{
 				if( $oCv->list_fields_name[$name] == '')
 					$fieldname = 'crmid';
 				else
 					$fieldname = $oCv->list_fields_name[$name];
+
                         }else
                         {
 				if( $focus->list_fields_name[$name] == '')
@@ -125,6 +128,10 @@ function getSearchListHeaderValues($focus, $module,$sort_qry='',$sorder='',$orde
 				$fieldname = "contact_id";
 			if($fieldname == "accountname" && $module !="Accounts")
 				$fieldname = "account_id";
+			if($fieldname == "productname" && $module =="Campaigns")
+				$fieldname = "product_id";
+
+
                 }
 		else
                 {
@@ -135,7 +142,7 @@ function getSearchListHeaderValues($focus, $module,$sort_qry='',$sorder='',$orde
 
 			if($fieldname == "lastname" && $module !="Leads" && $module !="Contacts")
                                 $fieldname = "contact_id";
-                }
+		}
                 if($is_admin == true || $profileGlobalPermission[1] == 0 || $profileGlobalPermission[2] ==0 || in_array($fieldname,$field))
 		{
 			if($fieldname!='parent_id')
@@ -144,12 +151,20 @@ function getSearchListHeaderValues($focus, $module,$sort_qry='',$sorder='',$orde
 				if($fieldname == 'contact_id' && $module !="Contacts") 
 				$name = $app_strings['LBL_CONTACT_LAST_NAME'];
 				elseif($fieldname == 'contact_id' && $module =="Contacts") 
-				$name = $mod_strings['Reports To']." - ".$mod_strings['LBL_LIST_LAST_NAME'];
+					$name = $mod_strings['Reports To']." - ".$mod_strings['LBL_LIST_LAST_NAME'];
 				//assign the translated string
-				$search_header[$fld_name] = getTranslatedString($name);
+				//added to fix #5205
+				//Added condition to hide the close column in calendar search header
+				if($name != $app_strings['Close'])
+					$search_header[$fld_name] = getTranslatedString($name);
 			}
+		}
+		if($module == 'HelpDesk' && $fieldname == 'crmid')
+		{
+                        $fld_name=$fieldname;
+                        $search_header[$fld_name] = getTranslatedString($name);
                 }
-        }
+	}
 	$log->debug("Exiting getSearchListHeaderValues method ...");	
         return $search_header;
 
@@ -177,9 +192,7 @@ function Search($module)
 		
 		$stringConvert = function_exists(iconv) ? @iconv("UTF-8",$default_charset,$search_string) : $search_string;
 
-		$search_string=addslashes(ltrim(rtrim($stringConvert)));
-
-		// $search_string=addslashes(ltrim(rtrim($_REQUEST['search_text'])));
+		$search_string=trim($stringConvert);
 
         }
         if(isset($_REQUEST['searchtype']) && $_REQUEST['searchtype']!="")
@@ -197,8 +210,8 @@ function Search($module)
                 }
                 else //Global Search
                 {
-                }
-		$url_string = "&search_field=".$search_column."&search_text=".$search_string."&searchtype=BasicSearch";
+		}
+		$url_string = "&search_field=".$search_column."&search_text=".urlencode($search_string)."&searchtype=BasicSearch";
 		if(isset($_REQUEST['type']) && $_REQUEST['type'] != '')
 			$url_string .= "&type=".$_REQUEST['type'];
 		return $where."#@@#".$url_string;
@@ -220,8 +233,8 @@ function get_usersid($table_name,$column_name,$search_string)
 	global $log;
         $log->debug("Entering get_usersid(".$table_name.",".$column_name.",".$search_string.") method ...");
 	global $adb;
-	$user_qry="select distinct(vtiger_users.id)from vtiger_users inner join vtiger_crmentity on vtiger_crmentity.smownerid=vtiger_users.id where vtiger_users.user_name like '%".$search_string."%' ";
-	$user_result=$adb->query($user_qry);
+	$user_qry="select distinct(vtiger_users.id)from vtiger_users inner join vtiger_crmentity on vtiger_crmentity.smownerid=vtiger_users.id where vtiger_users.user_name like '" . formatForSqlLike($search_string) . "'";
+	$user_result=$adb->pquery($user_qry, array());
 	$noofuser_rows=$adb->num_rows($user_result);
 	$x=$noofuser_rows-1;
 	if($noofuser_rows!=0)
@@ -236,12 +249,11 @@ function get_usersid($table_name,$column_name,$search_string)
 				$where .= " or ";
 			}
 		}
-		$where.=" or vtiger_groups.groupname like '%".$search_string."%')";
+		$where.=" or vtiger_groups.groupname like '". formatForSqlLike($search_string) ."')";
 	}
 	else
 	{
-		//$where="$table_name.$column_name =''";
-		$where="vtiger_groups.groupname like '%".$search_string."%' ";
+		$where=" vtiger_groups.groupname like '". formatForSqlLike($search_string) ."' ";
 	}	
 	$log->debug("Exiting get_usersid method ...");
 	return $where;	
@@ -256,9 +268,13 @@ function get_usersid($table_name,$column_name,$search_string)
 
 function getValuesforColumns($column_name,$search_string,$criteria='cts')
 {
-	global $log;
+	global $log, $current_user;
 	$log->debug("Entering getValuesforColumns(".$column_name.",".$search_string.") method ...");
 	global $column_array,$table_col_array;
+
+	if($_REQUEST['type'] == "entchar")
+		$criteria = "is";
+
 	for($i=0; $i<count($column_array);$i++)
 	{
 		if($column_name == $column_array[$i])
@@ -272,19 +288,28 @@ function getValuesforColumns($column_name,$search_string,$criteria='cts')
 			}
 			else 
 			{
-				$where="(";
-				for($j=0;$j<count($explode_column);$j++)
-				{
-					$where .=getSearch_criteria($criteria,$search_string,$explode_column[$j]);
-					if($j != $x-1)
-					{
-						if($criteria == 'dcts' || $criteria == 'isn')
-							$where .= " and ";
-						else
-							$where .= " or ";
+				if($column_name == "contact_id" && $_REQUEST['type'] == "entchar") {
+					if (getFieldVisibilityPermission('Contacts', $current_user->id,'firstname') == '0') {
+						$where = "concat(vtiger_contactdetails.lastname, ' ', vtiger_contactdetails.firstname) = '$search_string'";
+					} else {
+						$where = "vtiger_contactdetails.lastname = '$search_string'";					
 					}
 				}
-				$where.=")";
+				else {
+					$where="(";
+					for($j=0;$j<count($explode_column);$j++)
+					{
+						$where .=getSearch_criteria($criteria,$search_string,$explode_column[$j]);
+						if($j != $x-1)
+						{
+							if($criteria == 'dcts' || $criteria == 'isn')
+								$where .= " and ";
+							else
+								$where .= " or ";
+						}
+					}
+					$where.=")";
+				}
 			}
 			break 1;
 		}
@@ -302,16 +327,16 @@ function getValuesforColumns($column_name,$search_string,$criteria='cts')
 
 function BasicSearch($module,$search_field,$search_string)
 {
-	 global $log;
+	 global $log,$mod_strings,$current_user;
          $log->debug("Entering BasicSearch(".$module.",".$search_field.",".$search_string.") method ...");
 	global $adb;
-	$search_string = ltrim(rtrim($search_string));
+	$search_string = ltrim(rtrim(mysql_real_escape_string($search_string)));
 	global $column_array,$table_col_array;
 	if($search_field =='crmid')
 	{
 		$column_name='crmid';
 		$table_name='vtiger_crmentity';
-		$where="$table_name.$column_name like '%".$search_string."%'";
+		$where="$table_name.$column_name like '". formatForSqlLike($search_string) ."'";
 	}else
 	{	
 		//Check added for tickets by accounts/contacts in dashboard
@@ -321,34 +346,36 @@ function BasicSearch($module,$search_field,$search_string)
 			$search_field = "parent_id";
 		}
 		//Check ends
-		
+
 		//Added to search contact name by lastname
 		if(($module == "Calendar" || $module == "Invoice" || $module == "Notes" || $module == "SalesOrder" || $module== "PurchaseOrder") && ($search_field == "contact_id"))
-	       {
-	                 $module = 'Contacts';
-	                 $search_field = 'lastname';
-	       }
+		{
+			$module = 'Contacts';
+			$search_field = 'lastname';
+		}
 		if($search_field == "accountname" && $module != "Accounts")
 			$search_field = "account_id";
-		$qry="select vtiger_field.columnname,tablename from vtiger_tab inner join vtiger_field on vtiger_field.tabid=vtiger_tab.tabid where vtiger_tab.name='".$module."' and (fieldname='".$search_field."' or columnname='".$search_field."')";
-		$result = $adb->query($qry);
+		if($search_field == 'productname' && $module == 'Campaigns')
+			$search_field = "product_id";
+		$qry="select vtiger_field.columnname,tablename from vtiger_tab inner join vtiger_field on vtiger_field.tabid=vtiger_tab.tabid where vtiger_tab.name=? and (fieldname=? or columnname=?)";
+		$result = $adb->pquery($qry, array($module, $search_field, $search_field));
 		$noofrows = $adb->num_rows($result);
 		if($noofrows!=0)
 		{
 			$column_name=$adb->query_result($result,0,'columnname');	
-			
+
 			//Check added for tickets by accounts/contacts in dashboard
 			if ($column_name == 'parent_id')
-		        {
+			{
 				if ($search_field_first	== 'account_id') $search_field_first = 'accountid';
 				if ($search_field_first	== 'contactid') $search_field_first = 'contact_id';
 				$column_name = $search_field_first;
 			}
-				
+
 			//Check ends
 			$table_name=$adb->query_result($result,0,'tablename');
 			$uitype=getUItype($module,$column_name);
-			
+
 			//Added for Member of search in Accounts
 			if($column_name == "parentid" && $module == "Accounts")
 			{
@@ -377,29 +404,68 @@ function BasicSearch($module,$search_field,$search_string)
 			// Added to fix errors while searching check box type fields(like product active. ie. they store 0 or 1. we search them as yes or no) in basic search.
 			if ($uitype == 56)
 			{
-				if(stristr($search_string,'yes'))
+				if(strtolower($search_string) == 'yes')
 					$where="$table_name.$column_name = '1'";
-				elseif(stristr($search_string,'no'))
+				elseif(strtolower($search_string) == 'no')
 					$where="$table_name.$column_name = '0'";
 				else
-					$where="$table_name.$column_name = '$search_string'";
+					$where="$table_name.$column_name = '-1'";
 
 			}
+			elseif ($uitype == 111 || $uitype == 15 || $uitype == 16)
+			{
+				if(is_uitype($uitype, '_picklist_')) 
+				{ 
+					// Get all the keys for the for the Picklist value
+					$mod_keys = array_keys($mod_strings, $search_string);
+					if(sizeof($mod_keys) >= 1)
+					{
+						// Iterate on the keys, to get the first key which doesn't start with LBL_      (assuming it is not used in PickList)
+						foreach($mod_keys as $mod_idx=>$mod_key) 
+						{
+							$stridx = strpos($mod_key, 'LBL_');
+							// Use strict type comparision, refer strpos for more details
+							if ($stridx !== 0) 
+							{
+								$search_string = $mod_key;
+								if(getFieldVisibilityPermission("Calendar", $current_user->id,'taskstatus') == '0' && ($tab_col == "vtiger_activity.status" || $tab_col == "vtiger_activity.eventstatus"))
+								{
+										$where="(vtiger_activity.status like '". formatForSqlLike($search_string) ."' or vtiger_activity.eventstatus like '". formatForSqlLike($search_string) ."')";
+								}
+								else
+									$where="$table_name.$column_name like '". formatForSqlLike($search_string) ."'";
+								break;
+							}
+							else //if the mod strings cointains LBL , just return the original search string. Not the key
+								$where="$table_name.$column_name like '". formatForSqlLike($search_string) ."'";
+						}
+					}
+					else
+					{
+						if(getFieldVisibilityPermission("Calendar", $current_user->id,'taskstatus') == '0' && ($table_name == "vtiger_activity" && ($column_name == "status" || $column_name == "eventstatus")))
+						{
+								$where="(vtiger_activity.status like '". formatForSqlLike($search_string) ."' or vtiger_activity.eventstatus like '". formatForSqlLike($search_string) ."')";
+						}
+						else
+							$where="$table_name.$column_name like '". formatForSqlLike($search_string) ."'";
+					}
+				}
+			}
 			elseif($table_name == "vtiger_crmentity" && $column_name == "smownerid")
 			{
 				$where = get_usersid($table_name,$column_name,$search_string);
 			}
-			elseif($table_name == "vtiger_activity" && $column_name == "status")
-			{
-				$where="($table_name.$column_name like '%".$search_string."%' or vtiger_activity.eventstatus like '%".$search_string."%')";
-			}
 			else if(in_array($column_name,$column_array))
 			{
 				$where = getValuesforColumns($column_name,$search_string);
 			}
+			else if($_REQUEST['type'] == 'entchar')
+			{
+				$where="$table_name.$column_name = '". $search_string ."'";
+			}
 			else
 			{
-				$where="$table_name.$column_name like '%".$search_string."%'";
+				$where="$table_name.$column_name like '". formatForSqlLike($search_string) ."'";
 			}
 		}
 	}
@@ -412,12 +478,13 @@ function BasicSearch($module,$search_field,$search_string)
 		else
 			$where = "(".$where_cond0." or ".$where_cond1.")";
 	}
-	if($_REQUEST['type'] == 'entchar')
+	// commented to support searching "%" with the search string.
+	/*if($_REQUEST['type'] == 'entchar')
 	{
 		$search = array('Un Assigned','%','like');
 		$replace = array('','','=');
 		$where= str_replace($search,$replace,$where);
-	}
+	}*/
 	if($_REQUEST['type'] == 'alpbt')
 	{
 	        $where = str_replace_once("%", "", $where);
@@ -447,7 +514,7 @@ function getAdvSearchfields($module)
 	if($is_admin == true || $profileGlobalPermission[1] == 0 || $profileGlobalPermission[2] == 0)
 	{
 		$sql = "select * from vtiger_field ";
-		$sql.= " where vtiger_field.tabid in(".$tabid.") and";
+		$sql.= " where vtiger_field.tabid in(?) and";
 		$sql.= " vtiger_field.displaytype in (1,2,3)";
 		if($tabid == 13 || $tabid == 15)
 		{
@@ -469,15 +536,24 @@ function getAdvSearchfields($module)
 		{
 			$sql.= " and vtiger_field.fieldlabel != 'Attachment'";
 		}
-		$sql.= "group by vtiger_field.fieldlabel order by block,sequence";
+		$sql.= " group by vtiger_field.fieldlabel order by block,sequence";
+		
+		$params = array($tabid);
 	}
 	else
 	{
 		$profileList = getCurrentUserProfileList();
 		$sql = "select * from vtiger_field inner join vtiger_profile2field on vtiger_profile2field.fieldid=vtiger_field.fieldid inner join vtiger_def_org_field on vtiger_def_org_field.fieldid=vtiger_field.fieldid ";
-		$sql.= " where vtiger_field.tabid in(".$tabid.") and";
-		$sql.= " vtiger_field.displaytype in (1,2,3) and vtiger_profile2field.visible=0";
-		$sql.= " and vtiger_def_org_field.visible=0  and vtiger_profile2field.profileid in ".$profileList;
+		$sql.= " where vtiger_field.tabid in(?) and";
+		$sql.= " vtiger_field.displaytype in (1,2,3) and vtiger_profile2field.visible=0 and vtiger_def_org_field.visible=0";
+		
+		$params = array($tabid);
+		
+		if (count($profileList) > 0) {
+			$sql.= "  and vtiger_profile2field.profileid in (". generateQuestionMarks($profileList) .")";	
+			array_push($params, $profileList);		
+		}
+		
 		if($tabid == 13 || $tabid == 15)
 		{
 			$sql.= " and vtiger_field.fieldlabel != 'Add Comment'";
@@ -499,10 +575,9 @@ function getAdvSearchfields($module)
 			$sql.= " and vtiger_field.fieldlabel != 'Attachment'";
 		}
 		$sql .= " group by vtiger_field.fieldlabel order by block,sequence";
-
 	}
 
-	$result = $adb->query($sql);
+	$result = $adb->pquery($sql, $params);
 	$noofrows = $adb->num_rows($result);
 	$block = '';
 	$select_flag = '';
@@ -536,7 +611,7 @@ function getAdvSearchfields($module)
 				$module_columnlist['vtiger_activity:time_start::Activities_Start Time:I'] = 'Start Time';
 
 		}
-		$fieldlabel1 = str_replace(" ","_",$fieldlabel);
+		//$fieldlabel1 = str_replace(" ","_",$fieldlabel); // Is not used anywhere
 		//Check added to search the lists by Inventory manager
                 if($fieldtablename == 'vtiger_quotes' && $fieldcolname == 'inventorymanager')
                 {
@@ -553,30 +628,39 @@ function getAdvSearchfields($module)
 			if ($i==0)
 				$select_flag = "selected";
 
+			$mod_fieldlabel = $mod_strings[$fieldlabel];
+			if($mod_fieldlabel =="") $mod_fieldlabel = $fieldlabel;	
+
 			if($fieldlabel == "Product Code")
-				$OPTION_SET .= "<option value=\'".$fieldtablename.".".$fieldcolname."::::".$fieldtypeofdata."\'".$select_flag.">".$mod_strings[$fieldlabel]."</option>";
+				$OPTION_SET .= "<option value=\'".$fieldtablename.".".$fieldcolname."::::".$fieldtypeofdata."\'".$select_flag.">".$mod_fieldlabel."</option>";
 			if($fieldlabel == "Reports To")
-				$OPTION_SET .= "<option value=\'".$fieldtablename.".".$fieldcolname."::::".$fieldtypeofdata."\'".$select_flag.">".$mod_strings[$fieldlabel]." - ".$mod_strings['LBL_LIST_LAST_NAME']."</option>";
+				$OPTION_SET .= "<option value=\'".$fieldtablename.".".$fieldcolname."::::".$fieldtypeofdata."\'".$select_flag.">".$mod_fieldlabel." - ".$mod_strings['LBL_LIST_LAST_NAME']."</option>";
 			elseif($fieldcolname == "contactid" || $fieldcolname == "contact_id")
 			{
 				$OPTION_SET .= "<option value=\'vtiger_contactdetails.lastname::::".$fieldtypeofdata."\' ".$select_flag.">".$app_strings['LBL_CONTACT_LAST_NAME']."</option>";
 				$OPTION_SET .= "<option value=\'vtiger_contactdetails.firstname::::".$fieldtypeofdata."\'>".$app_strings['LBL_CONTACT_FIRST_NAME']."</option>";
 			}
 			elseif($fieldcolname == "campaignid")
-				$OPTION_SET .= "<option value=\'vtiger_campaign.campaignname::::".$fieldtypeofdata."\' ".$select_flag.">".$mod_strings[$fieldlabel]."</option>";
+				$OPTION_SET .= "<option value=\'vtiger_campaign.campaignname::::".$fieldtypeofdata."\' ".$select_flag.">".$mod_fieldlabel."</option>";
 			else
-				$OPTION_SET .= "<option value=\'".$fieldtablename.".".$fieldcolname."::::".$fieldtypeofdata."\' ".$select_flag.">".$fieldlabel."</option>";
+				$OPTION_SET .= "<option value=\'".$fieldtablename.".".$fieldcolname."::::".$fieldtypeofdata."\' ".$select_flag.">".str_replace("'","`",$fieldlabel)."</option>";
 		}
 	}
 	//Added to include Ticket ID in HelpDesk advance search
 	if($module == 'HelpDesk')
 	{
-		$OPTION_SET .= "<option value=\'vtiger_crmentity.crmid::::".$fieldtypeofdata."\'>".$mod_strings['Ticket ID']."</option>";
+		$mod_fieldlabel = $mod_strings['Ticket ID'];
+                if($mod_fieldlabel =="") $mod_fieldlabel = 'Ticket ID';
+
+		$OPTION_SET .= "<option value=\'vtiger_crmentity.crmid::::".$fieldtypeofdata."\'>".$mod_fieldlabel."</option>";
 	}
 	//Added to include activity type in activity advance search
 	if($module == 'Activities')
 	{
-		$OPTION_SET .= "<option value=\'vtiger_activity.activitytype::::".$fieldtypeofdata."\'>".$mod_strings['Activity Type']."</option>";
+		$mod_fieldlabel = $mod_strings['Activity Type'];
+                if($mod_fieldlabel =="") $mod_fieldlabel = 'Activity Type';
+				
+		$OPTION_SET .= "<option value=\'vtiger_activity.activitytype::::".$fieldtypeofdata."\'>".$mod_fieldlabel."</option>";
 	}
 	$log->debug("Exiting getAdvSearchfields method ...");
 	return $OPTION_SET;
@@ -591,7 +675,7 @@ function getcriteria_options()
 {
 	global $log,$app_strings;
 	$log->debug("Entering getcriteria_options() method ...");
-	$CRIT_OPT = "<option value=\'cts\'>".$app_strings['contains']."</option><option value=\'dcts\'>".$app_strings['does_not_contains']."</option><option value=\'is\'>".$app_strings['is']."</option><option value=\'isn\'>".$app_strings['is_not']."</option><option value=\'bwt\'>".$app_strings['begins_with']."</option><option value=\'ewt\'>".$app_strings['ends_with']."</option><option value=\'grt\'>".$app_strings['greater_than']."</option><option value=\'lst\'>".$app_strings['less_than']."</option><option value=\'grteq\'>".$app_strings['greater_or_equal']."</option><option value=\'lsteq\'>".$app_strings['less_or_equal']."</option>";
+	$CRIT_OPT = "<option value=\'cts\'>".str_replace("'","`",$app_strings['contains'])."</option><option value=\'dcts\'>".str_replace("'","`",$app_strings['does_not_contains'])."</option><option value=\'is\'>".str_replace("'","`",$app_strings['is'])."</option><option value=\'isn\'>".str_replace("'","`",$app_strings['is_not'])."</option><option value=\'bwt\'>".str_replace("'","`",$app_strings['begins_with'])."</option><option value=\'ewt\'>".str_replace("'","`",$app_strings['ends_with'])."</option><option value=\'grt\'>".str_replace("'","`",$app_strings['greater_than'])."</option><option value=\'lst\'>".str_replace("'","`",$app_strings['less_than'])."</option><option value=\'grteq\'>".str_replace("'","`",$app_strings['greater_or_equal'])."</option><option value=\'lsteq\'>".str_replace("'","`",$app_strings['less_or_equal'])."</option>";
 	$log->debug("Exiting getcriteria_options method ...");
 	return $CRIT_OPT;
 }
@@ -622,7 +706,7 @@ function getSearch_criteria($criteria,$searchstring,$searchfield)
 	switch($criteria)
 	{
 		case 'cts':
-			$where_string = $searchfield." like '%".$searchstring."%' ";
+			$where_string = $searchfield." like '". formatForSqlLike($searchstring) ."' ";
 			if($searchstring == NULL)
 			{
 					$where_string = "(".$searchfield." like '' or ".$searchfield." is NULL)";
@@ -631,9 +715,9 @@ function getSearch_criteria($criteria,$searchstring,$searchfield)
 		
 		case 'dcts':
 			if($searchfield == "vtiger_users.user_name" || $searchfield =="vtiger_groups.groupname")	
-				$where_string = "(".$searchfield." not like '%".$searchstring."%')";
+				$where_string = "(".$searchfield." not like '". formatForSqlLike($searchstring) ."')";
 			else
-				$where_string = "(".$searchfield." not like '%".$searchstring."%' or ".$searchfield." is null)";
+				$where_string = "(".$searchfield." not like '". formatForSqlLike($searchstring) ."' or ".$searchfield." is null)";
 			if($searchstring == NULL)
 			$where_string = "(".$searchfield." not like '' or ".$searchfield." is not NULL)";
 			break;
@@ -650,15 +734,15 @@ function getSearch_criteria($criteria,$searchstring,$searchfield)
 			else	
 				$where_string = "(".$searchfield." <> '".$searchstring."' or ".$searchfield." is null)";
 			if($searchstring == NULL)
-			$where_string = "(".$searchfield." not like '' or ".$searchfield." is not NULL)";
+			$where_string = "(".$searchfield." not like '' and ".$searchfield." is not NULL)";
 			break;
 			
 		case 'bwt':
-			$where_string = $searchfield." like '".$searchstring."%' ";
+			$where_string = $searchfield." like '". formatForSqlLike($searchstring, 2) ."' ";
 			break;
 
 		case 'ewt':
-			$where_string = $searchfield." like '%".$searchstring."' ";
+			$where_string = $searchfield." like '". formatForSqlLike($searchstring, 1) ."' ";
 			break;
 
 		case 'grt':
@@ -691,7 +775,7 @@ function getSearch_criteria($criteria,$searchstring,$searchfield)
 function getWhereCondition($currentModule)
 {
 	global $log,$default_charset;
-	global $column_array,$table_col_array;
+	global $column_array,$table_col_array,$mod_strings,$current_user;
 
         $log->debug("Entering getWhereCondition(".$currentModule.") method ...");
 	
@@ -717,38 +801,83 @@ function getWhereCondition($currentModule)
 			list($tab_col_val,$typeofdata) = split("::::",$_REQUEST[$table_colname]);
 			$tab_col = str_replace('\'','',stripslashes($tab_col_val));
 			$srch_cond = str_replace('\'','',stripslashes($_REQUEST[$search_condition]));
-			$srch_val = addslashes($_REQUEST[$search_value]);
+			$srch_val = $_REQUEST[$search_value];
 			$srch_val = function_exists(iconv) ? @iconv("UTF-8",$default_charset,$srch_val) : $srch_val;
+			$url_string .="&Fields".$i."=".$tab_col."&Condition".$i."=".$srch_cond."&Srch_value".$i."=".urlencode($srch_val);
+			$srch_val = mysql_real_escape_string($srch_val);
 			list($tab_name,$column_name) = split("[.]",$tab_col);
-			$url_string .="&Fields".$i."=".$tab_col."&Condition".$i."=".$srch_cond."&Srch_value".$i."=".$srch_val;
 			$uitype=getUItype($currentModule,$column_name);
 			//added to allow  search in check box type fields(ex: product active. it will contain 0 or 1) using yes or no instead of 0 or 1
 			if ($uitype == 56)
 			{
-				if(stristr($srch_val,'yes'))
-                                        $adv_string .= " ".getSearch_criteria($srch_cond,"1",$tab_name.'.'.$column_name)." ".$matchtype;
-                                elseif(stristr($srch_val,'no'))
-                                        $adv_string .= " ".getSearch_criteria($srch_cond,"0",$tab_name.'.'.$column_name)." ".$matchtype;
+				if(strtolower($srch_val) == 'yes')
+                	$adv_string .= " ".getSearch_criteria($srch_cond,"1",$tab_name.'.'.$column_name)." ".$matchtype;
+				elseif(strtolower($srch_val) == 'no')
+                	$adv_string .= " ".getSearch_criteria($srch_cond,"0",$tab_name.'.'.$column_name)." ".$matchtype;
 				else
-                                        $adv_string .= " ".getSearch_criteria($srch_cond,$srch_val,$tab_name.'.'.$column_name)." ".$matchtype;
+					$adv_string .= " ".getSearch_criteria($srch_cond,"-1",$tab_name.'.'.$column_name)." ".$matchtype;
 			}
+			elseif ($uitype == 111 || $uitype == 15 || $uitype == 16)
+			{
+				if(is_uitype($uitype, '_picklist_')) { 
+					// Get all the keys for the for the Picklist value
+					$mod_keys = array_keys($mod_strings, $srch_val);
+					if(sizeof($mod_keys) >= 1)
+					{
+						// Iterate on the keys, to get the first key which doesn't start with LBL_      (assuming it is not used in PickList)
+						foreach($mod_keys as $mod_idx=>$mod_key) {
+							$stridx = strpos($mod_key, 'LBL_');
+							// Use strict type comparision, refer strpos for more details
+							if ($stridx !== 0) 
+							{	
+								$srch_val = $mod_key;
+								if(getFieldVisibilityPermission("Calendar", $current_user->id,'taskstatus') == '0' && ($tab_col == "vtiger_activity.status" || $tab_col == "vtiger_activity.eventstatus"))
+								{
+										if($srch_cond == 'dcts' || $srch_cond == 'isn' || $srch_cond == 'is')
+											$re_cond = "and";
+										else
+											$re_cond = "or";
+										if($srch_cond == 'is' && $srch_val !='')
+											$re_cond = "or";
+
+										$adv_string .= " (".getSearch_criteria($srch_cond,$srch_val,'vtiger_activity.status')." ".$re_cond;
+										$adv_string .= " ".getSearch_criteria($srch_cond,$srch_val,'vtiger_activity.eventstatus')." )".$matchtype;	
+								}
+								else
+									$adv_string .= " ".getSearch_criteria($srch_cond,$srch_val,$tab_name.'.'.$column_name)." ".$matchtype;
+								break;
+							}
+							else //if the key contains the LBL, then return the original srch_val.
+								$adv_string .= " ".getSearch_criteria($srch_cond,$srch_val,$tab_name.'.'.$column_name)." ".$matchtype;
+
+						}
+
+					}
+					else
+					{
+						if(getFieldVisibilityPermission("Calendar", $current_user->id,'taskstatus') == '0' && ($tab_col == "vtiger_activity.status" || $tab_col == "vtiger_activity.eventstatus"))
+						{
+								if($srch_cond == 'dcts' || $srch_cond == 'isn' || $srch_cond == 'is')
+									$re_cond = "and";
+								else
+									$re_cond = "or";
+								if($srch_cond == 'is' && $srch_val !='')
+									$re_cond = "or";
+
+								$adv_string .= " (".getSearch_criteria($srch_cond,$srch_val,'vtiger_activity.status')." ".$re_cond;
+								$adv_string .= " ".getSearch_criteria($srch_cond,$srch_val,'vtiger_activity.eventstatus')." )".$matchtype;	
+						}
+						else
+							$adv_string .= " ".getSearch_criteria($srch_cond,$srch_val,$tab_col)." ".$matchtype;
+					}
+				}
+			}
+
 			elseif($tab_col == "vtiger_crmentity.smownerid")
 			{
 				$adv_string .= " (".getSearch_criteria($srch_cond,$srch_val,'vtiger_users.user_name')." or";	
 				$adv_string .= " ".getSearch_criteria($srch_cond,$srch_val,'vtiger_groups.groupname')." )".$matchtype;	
 			}
-			elseif($tab_col == "vtiger_activity.status")
-			{
-				if($srch_cond == 'dcts' || $srch_cond == 'isn' || $srch_cond == 'is')
-					$re_cond = "and";
-				else
-					$re_cond = "or";
-				if($srch_cond == 'is' && $srch_val !='')
-					$re_cond = "or";
-
-				$adv_string .= " (".getSearch_criteria($srch_cond,$srch_val,'vtiger_activity.status')." ".$re_cond;
-				$adv_string .= " ".getSearch_criteria($srch_cond,$srch_val,'vtiger_activity.eventstatus')." )".$matchtype;	
-			}
 			elseif($tab_col == "vtiger_cntactivityrel.contactid")
 			{
 				$adv_string .= " (".getSearch_criteria($srch_cond,$srch_val,'vtiger_contactdetails.firstname')." or";	
@@ -756,7 +885,7 @@ function getWhereCondition($currentModule)
 			}
 			elseif(in_array($column_name,$column_array))
                         {
-                                $adv_string .= getValuesforColumns($column_name,$srch_val,$srch_cond)." ".$matchtype;
+                                $adv_string .= " ".getValuesforColumns($column_name,$srch_val,$srch_cond)." ".$matchtype;
                         }
 			else
 			{
@@ -822,8 +951,8 @@ function getdashboardcondition()
 		$url_string .= "&date_closed=".$date_closed;
 	}
 	if(isset($owner) && $owner != ""){
-		$user_qry="select vtiger_users.id from vtiger_users where vtiger_users.user_name = '".$owner."' ";
-		$res = $adb->query($user_qry);
+		$user_qry="select vtiger_users.id from vtiger_users where vtiger_users.user_name = ?";
+		$res = $adb->pquery($user_qry, array($owner));
 		$uid = $adb->query_result($res,0,'id');
 		array_push($where_clauses, "vtiger_crmentity.smownerid = ".$uid);
 		$url_string .= "&assigned_user_id=".$uid;
