@@ -34,7 +34,7 @@ require_once('modules/Users/Users.php');
 class Emails extends CRMEntity {
 	var $log;
 	var $db;
-
+	var $table_name = "vtiger_activity";
 	// Stored vtiger_fields
   	// added to check email save from plugin or not
 	var $plugin_save = false;
@@ -108,8 +108,8 @@ var $rel_serel_table = "vtiger_seactivityrel";
 					if(!$parentid) {
 						$parentid = $adb->getUniqueID('vtiger_seactivityrel');
 					}
-					$mysql='insert into vtiger_seactivityrel values('.$parentid.','.$actid.')';
-					$adb->query($mysql);
+					$mysql='insert into vtiger_seactivityrel values(?,?)';
+					$adb->pquery($mysql, array($parentid, $actid));
 				}
 				else
 				{	  
@@ -120,10 +120,19 @@ var $rel_serel_table = "vtiger_seactivityrel";
 						$mycrmid=$realid[0];
 						//added to handle the relationship of emails with vtiger_users
 						if($realid[1] == -1)
-							$mysql='insert into vtiger_salesmanactivityrel values('.$mycrmid.','.$actid.')';
-						else	
-							$mysql='insert into vtiger_seactivityrel values('.$mycrmid.','.$actid.')';
-						$adb->query($mysql);
+						{
+							$del_q = 'delete from vtiger_salesmanactivityrel where smid=? and activityid=?';
+                                                        $adb->pquery($del_q,array($mycrmid, $actid));
+							$mysql='insert into vtiger_salesmanactivityrel values(?,?)';
+						}
+						else
+						{
+							$del_q = 'delete from vtiger_seactivityrel where crmid=? and activityid=?';
+							$adb->pquery($del_q,array($mycrmid, $actid));
+							$mysql='insert into vtiger_seactivityrel values(?,?)';
+						}	
+						$params = array($mycrmid, $actid);
+						$adb->pquery($mysql, $params);
 					}
 				}
 			}
@@ -164,21 +173,122 @@ var $rel_serel_table = "vtiger_seactivityrel";
 		$log->debug("Entering into insertIntoAttachment($id,$module) method.");
 		
 		$file_saved = false;
+		
+		//Added to send generated Invoice PDF with mail
+		$pdfAttached = $_REQUEST['pdf_attachment'];
+		//created Invoice pdf is attached with the mail
+			if(isset($_REQUEST['pdf_attachment']) && $_REQUEST['pdf_attachment'] !='')
+			{
+				$file_saved = pdfAttach($this,$module,$pdfAttached,$id);
+			}
 
 		//This is to added to store the existing attachment id of the contact where we should delete this when we give new image
-
 		foreach($_FILES as $fileindex => $files)
 		{
 			if($files['name'] != '' && $files['size'] > 0)
 			{
+				$files['original_name'] = $_REQUEST[$fileindex.'_hidden'];
 				$file_saved = $this->uploadAndSaveFile($id,$module,$files);
 			}
 		}
+		if($module == 'Emails' && isset($_REQUEST['att_id_list']) && $_REQUEST['att_id_list'] != '')
+		{
+			$att_lists = explode(";",$_REQUEST['att_id_list'],-1);
+			$id_cnt = count($att_lists);
+			if($id_cnt != 0)
+			{
+				for($i=0;$i<$id_cnt;$i++)
+				{
+					$sql_rel='insert into vtiger_seattachmentsrel values(?,?)';
+		                        $adb->pquery($sql_rel, array($id, $att_lists[$i]));
+				}
+			}			
+		}
+		if($_REQUEST['att_module'] == 'Webmails')
+		{
+			require_once("modules/Webmails/Webmails.php");
+		        require_once("modules/Webmails/MailParse.php");
+		        require_once('modules/Webmails/MailBox.php');
+		        //$mailInfo = getMailServerInfo($current_user);
+			//$temprow = $adb->fetch_array($mailInfo);
 
+		        $MailBox = new MailBox($_REQUEST["mailbox"]);
+		        $mbox = $MailBox->mbox;
+		        $webmail = new Webmails($mbox,$_REQUEST['mailid']);
+		        $array_tab = Array();
+		        $webmail->loadMail($array_tab);
+			if(isset($webmail->att_details)){
+			foreach($webmail->att_details as $fileindex => $files)
+			{
+				if($files['name'] != '' && $files['size'] > 0)
+				{
+					//print_r($files);
+					$file_saved = $this->saveForwardAttachments($id,$module,$files);
+				}
+			}
+			}
+		}
 		$log->debug("Exiting from insertIntoAttachment($id,$module) method.");
 	}	
 	
-
+	function saveForwardAttachments($id,$module,$file_details)
+	{
+		global $log;
+                $log->debug("Entering into saveForwardAttachments($id,$module,$file_details) method.");
+                global $adb, $current_user;
+		global $upload_badext;
+		require_once('modules/Webmails/MailBox.php');
+                $mailbox=$_REQUEST["mailbox"];
+		$MailBox = new MailBox($mailbox);
+		$mail = $MailBox->mbox;
+		$binFile = preg_replace('/\s+/', '_', $file_details['name']);//replace space with _ in filename
+                $ext_pos = strrpos($binFile, ".");
+                $ext = substr($binFile, $ext_pos + 1);
+                if (in_array($ext, $upload_badext))
+                {
+                    $binFile .= ".txt";
+                }
+		//$filename = basename($binFile);
+		$filename = ltrim(basename(" ".$binFile)); //allowed filename like UTF-8 characters 
+		$filetype= $file_details['type'];
+		$filesize = $file_details['size'];
+		$filepart = $file_details['part'];
+		$transfer = $file_details['transfer'];
+		$file = imap_fetchbody($mail,$_REQUEST['mailid'],$filepart);
+		if ($transfer == 'BASE64')
+			    $file = imap_base64($file);
+		elseif($transfer == 'QUOTED-PRINTABLE')
+			    $file = imap_qprint($file);
+		$current_id = $adb->getUniqueID("vtiger_crmentity");
+		$date_var = date('YmdHis');
+		//to get the owner id
+		$ownerid = $this->column_fields['assigned_user_id'];
+		if(!isset($ownerid) || $ownerid=='')
+			$ownerid = $current_user->id;
+		$upload_file_path = decideFilePath();
+		file_put_contents ($upload_file_path.$current_id."_".$filename,$file);
+		
+                        $sql1 = "insert into vtiger_crmentity (crmid,smcreatorid,smownerid,setype,description,createdtime,modifiedtime) values(?,?,?,?,?,?,?)";
+                        $params1 = array($current_id, $current_user->id, $ownerid, $module." Attachment", $this->column_fields['description'], $adb->formatDate($date_var, true), $adb->formatDate($date_var, true));
+						$adb->pquery($sql1, $params1);
+						
+                        $sql2="insert into vtiger_attachments(attachmentsid, name, description, type, path) values(?,?,?,?,?)";
+                        $params2 = array($current_id, $filename, $this->column_fields['description'], $filetype, $upload_file_path);
+						$result=$adb->pquery($sql2, $params2);
+						
+                        if($_REQUEST['mode'] == 'edit')
+                        {
+                        	if($id != '' && $_REQUEST['fileid'] != '')
+                            {
+                                $delquery = 'delete from vtiger_seattachmentsrel where crmid = ? and attachmentsid = ?';
+		                        $adb->pquery($delquery, array($id, $_REQUEST['fileid']));
+			        		}
+						}
+                        $sql3='insert into vtiger_seattachmentsrel values(?,?)';
+                        $adb->pquery($sql3, array($id, $current_id));
+                        return true;
+		$log->debug("exiting from  saveforwardattachment function.");
+	}
 	/** Returns a list of the associated contacts
 	 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc..
 	 * All Rights Reserved..
@@ -256,8 +366,8 @@ var $rel_serel_table = "vtiger_seactivityrel";
 
 		$id = $_REQUEST['record'];
 
-		$query = 'SELECT vtiger_users.id, vtiger_users.first_name,vtiger_users.last_name, vtiger_users.user_name, vtiger_users.email1, vtiger_users.email2, vtiger_users.yahoo_id, vtiger_users.phone_home, vtiger_users.phone_work, vtiger_users.phone_mobile, vtiger_users.phone_other, vtiger_users.phone_fax from vtiger_users inner join vtiger_salesmanactivityrel on vtiger_salesmanactivityrel.smid=vtiger_users.id and vtiger_salesmanactivityrel.activityid='.$adb->quote($id);
-		$result=$adb->query($query);   
+		$query = 'SELECT vtiger_users.id, vtiger_users.first_name,vtiger_users.last_name, vtiger_users.user_name, vtiger_users.email1, vtiger_users.email2, vtiger_users.yahoo_id, vtiger_users.phone_home, vtiger_users.phone_work, vtiger_users.phone_mobile, vtiger_users.phone_other, vtiger_users.phone_fax from vtiger_users inner join vtiger_salesmanactivityrel on vtiger_salesmanactivityrel.smid=vtiger_users.id and vtiger_salesmanactivityrel.activityid=?';
+		$result=$adb->pquery($query, array($id));   
 
 		$noofrows = $adb->num_rows($result);
 		$header [] = $app_strings['LBL_LIST_NAME'];
@@ -315,7 +425,7 @@ var $rel_serel_table = "vtiger_seactivityrel";
 		$query = "select vtiger_notes.title,'Notes      '  ActivityType, vtiger_notes.filename,
 		vtiger_attachments.type  FileType,crm2.modifiedtime lastmodified,
 		vtiger_seattachmentsrel.attachmentsid attachmentsid, vtiger_notes.notesid crmid,
-			crm2.createdtime, vtiger_notes.notecontent description, vtiger_users.user_name
+		vtiger_notes.notecontent description, vtiger_users.user_name
 		from vtiger_notes
 			inner join vtiger_senotesrel on vtiger_senotesrel.notesid= vtiger_notes.notesid
 			inner join vtiger_crmentity on vtiger_crmentity.crmid= vtiger_senotesrel.crmid
@@ -328,7 +438,7 @@ var $rel_serel_table = "vtiger_seactivityrel";
 		$query .= "select vtiger_attachments.description title ,'Attachments'  ActivityType,
 		vtiger_attachments.name filename, vtiger_attachments.type FileType,crm2.modifiedtime lastmodified,
 		vtiger_attachments.attachmentsid  attachmentsid,vtiger_seattachmentsrel.attachmentsid crmid,
-			crm2.createdtime, vtiger_attachments.description, vtiger_users.user_name
+		vtiger_attachments.description, vtiger_users.user_name
 		from vtiger_attachments
 			inner join vtiger_seattachmentsrel on vtiger_seattachmentsrel.attachmentsid= vtiger_attachments.attachmentsid
 			inner join vtiger_crmentity on vtiger_crmentity.crmid= vtiger_seattachmentsrel.crmid
@@ -403,8 +513,8 @@ var $rel_serel_table = "vtiger_seactivityrel";
 	{
 		global $log;
 		$log->debug("Entering set_emails_contact_invitee_relationship(".$email_id.",". $contact_id.") method ...");
-		$query = "insert into $this->rel_contacts_table (contactid,activityid) values('$contact_id','$email_id')";
-		$this->db->query($query,true,"Error setting email to contact relationship: "."<BR>$query");
+		$query = "insert into $this->rel_contacts_table (contactid,activityid) values(?,?)";
+		$this->db->pquery($query, array($contact_id, $email_id), true,"Error setting email to contact relationship: "."<BR>$query");
 		$log->debug("Exiting set_emails_contact_invitee_relationship method ...");
 	}
      
@@ -415,8 +525,8 @@ var $rel_serel_table = "vtiger_seactivityrel";
 	{
 		global $log;
 		$log->debug("Entering set_emails_se_invitee_relationship(".$email_id.",". $contact_id.") method ...");
-		$query = "insert into $this->rel_serel_table (crmid,activityid) values('$contact_id','$email_id')";
-		$this->db->query($query,true,"Error setting email to contact relationship: "."<BR>$query");
+		$query = "insert into $this->rel_serel_table (crmid,activityid) values(?,?)";
+		$this->db->pquery($query, array($contact_id, $email_id), true,"Error setting email to contact relationship: "."<BR>$query");
 		$log->debug("Exiting set_emails_se_invitee_relationship method ...");
 	}
      
@@ -427,8 +537,8 @@ var $rel_serel_table = "vtiger_seactivityrel";
 	{
 		global $log;
 		$log->debug("Entering set_emails_user_invitee_relationship(".$email_id.",". $user_id.") method ...");
-		$query = "insert into $this->rel_users_table (smid,activityid) values ('$user_id', '$email_id')";
-		$this->db->query($query,true,"Error setting email to user relationship: "."<BR>$query");
+		$query = "insert into $this->rel_users_table (smid,activityid) values (?,?)";
+		$this->db->pquery($query, array($user_id, $email_id), true,"Error setting email to user relationship: "."<BR>$query");
 		$log->debug("Exiting set_emails_user_invitee_relationship method ...");
 	}        
 
@@ -443,8 +553,10 @@ function get_to_emailids($module)
 	global $adb;
 	if(isset($_REQUEST["field_lists"]) && $_REQUEST["field_lists"] != "")
 	{
-		$query = 'select columnname,fieldid from vtiger_field where fieldid in('.ereg_replace(':',',',$_REQUEST["field_lists"]).')';
-		$result = $adb->query($query);
+		$field_lists = $_REQUEST["field_lists"];
+		if (is_string($field_lists)) $field_lists = explode(":", $field_lists);
+		$query = 'select columnname,fieldid from vtiger_field where fieldid in('. generateQuestionMarks($field_lists) .')';
+		$result = $adb->pquery($query, array($field_lists));
 		$columns = Array();
 		$idlists = '';
 		$mailids = '';
@@ -454,20 +566,38 @@ function get_to_emailids($module)
 			$fieldid[]=$row['fieldid'];
 		}
 		$columnlists = implode(',',$columns);
-		$crmids = ereg_replace(':',',',$_REQUEST["idlist"]);
+		$idstring = $_REQUEST["idlist"];
+                $single_record = false;
+		if(!strpos($idstring,':'))
+		{
+			$single_record = true;
+		}
+		$crmids = ereg_replace(':',',',$idstring);
+		$crmids = explode(",", $crmids);
 		switch($module)
 		{
 			case 'Leads':
-				$query = 'select crmid,concat(lastname," ",firstname) as entityname,'.$columnlists.' from vtiger_leaddetails inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_leaddetails.leadid left join vtiger_leadscf on vtiger_leadscf.leadid = vtiger_leaddetails.leadid where vtiger_crmentity.deleted=0 and ((ltrim(vtiger_leaddetails.email) != \'\') or (ltrim(vtiger_leaddetails.yahooid) != \'\')) and vtiger_crmentity.crmid in ('.$crmids.')';
+				$query = 'select crmid,concat(lastname," ",firstname) as entityname,'.$columnlists.' from vtiger_leaddetails inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_leaddetails.leadid left join vtiger_leadscf on vtiger_leadscf.leadid = vtiger_leaddetails.leadid where vtiger_crmentity.deleted=0 and ((ltrim(vtiger_leaddetails.email) != \'\') or (ltrim(vtiger_leaddetails.yahooid) != \'\')) and vtiger_crmentity.crmid in ('. generateQuestionMarks($crmids) .')';
 				break;
 			case 'Contacts':
-				$query = 'select crmid,concat(lastname," ",firstname) as entityname,'.$columnlists.' from vtiger_contactdetails inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_contactdetails.contactid left join vtiger_contactscf on vtiger_contactscf.contactid = vtiger_contactdetails.contactid where vtiger_crmentity.deleted=0 and ((ltrim(vtiger_contactdetails.email) != \'\')  or (ltrim(vtiger_contactdetails.yahooid) != \'\')) and vtiger_crmentity.crmid in ('.$crmids.')';
+				//email opt out funtionality works only when we do mass mailing.
+				if(!$single_record)
+				$concat_qry = '(((ltrim(vtiger_contactdetails.email) != \'\')  or (ltrim(vtiger_contactdetails.yahooid) != \'\')) and (vtiger_contactdetails.emailoptout != 1)) and ';
+				else
+				$concat_qry = '((ltrim(vtiger_contactdetails.email) != \'\')  or (ltrim(vtiger_contactdetails.yahooid) != \'\')) and ';
+				$query = 'select crmid,concat(lastname," ",firstname) as entityname,'.$columnlists.' from vtiger_contactdetails inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_contactdetails.contactid left join vtiger_contactscf on vtiger_contactscf.contactid = vtiger_contactdetails.contactid where vtiger_crmentity.deleted=0 and '.$concat_qry.'  vtiger_crmentity.crmid in ('. generateQuestionMarks($crmids) .')';
 				break;
 			case 'Accounts':
-				$query = 'select crmid,accountname as entityname,'.$columnlists.' from vtiger_account inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_account.accountid left join vtiger_accountscf on vtiger_accountscf.accountid = vtiger_account.accountid where vtiger_crmentity.deleted=0 and ((ltrim(vtiger_account.email1) != \'\') or (ltrim(vtiger_account.email2) != \'\')) and vtiger_crmentity.crmid in ('.$crmids.')';
+				//added to work out email opt out functionality.
+				if(!$single_record)
+					$concat_qry = '(((ltrim(vtiger_account.email1) != \'\') or (ltrim(vtiger_account.email2) != \'\')) and (vtiger_account.emailoptout != 1)) and ';
+				else
+					$concat_qry = '((ltrim(vtiger_account.email1) != \'\') or (ltrim(vtiger_account.email2) != \'\')) and ';
+					
+				$query = 'select crmid,accountname as entityname,'.$columnlists.' from vtiger_account inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_account.accountid left join vtiger_accountscf on vtiger_accountscf.accountid = vtiger_account.accountid where vtiger_crmentity.deleted=0 and '.$concat_qry.' vtiger_crmentity.crmid in ('. generateQuestionMarks($crmids) .')';
 				break;
 		}
-		$result = $adb->query($query);
+		$result = $adb->pquery($query, array($crmids));
 		while($row = $adb->fetch_array($result))
 		{
 			$name = $row['entityname'];
@@ -489,4 +619,49 @@ function get_to_emailids($module)
 	return $return_data;
 		
 }
+
+//added for attach the generated pdf with email
+function pdfAttach($obj,$module,$file_name,$id)
+{
+	global $log;
+	$log->debug("Entering into pdfAttach() method.");
+
+	global $adb, $current_user;
+	global $upload_badext;
+	$date_var = date('YmdHis');
+
+	$ownerid = $obj->column_fields['assigned_user_id'];
+	if(!isset($ownerid) || $ownerid=='')
+		$ownerid = $current_user->id;
+
+	$current_id = $adb->getUniqueID("vtiger_crmentity");
+
+	$upload_file_path = decideFilePath();
+
+	//Copy the file from temporary directory into storage directory for upload
+	$status = copy("storage/".$file_name,$upload_file_path.$current_id."_".$file_name);
+	//Check wheather the copy process is completed successfully or not. if failed no need to put entry in attachment table
+	if($status)
+	{
+		$query1 = "insert into vtiger_crmentity (crmid,smcreatorid,smownerid,setype,description,createdtime,modifiedtime) values(?,?,?,?,?,?,?)";
+		$params1 = array($current_id, $current_user->id, $ownerid, $module." Attachment", $obj->column_fields['description'], $adb->formatDate($date_var, true), $adb->formatDate($date_var, true));
+		$adb->pquery($query1, $params1);
+
+		$query2="insert into vtiger_attachments(attachmentsid, name, description, type, path) values(?,?,?,?,?)";
+		$params2 = array($current_id, $file_name, $obj->column_fields['description'], 'pdf', $upload_file_path);
+		$result=$adb->pquery($query2, $params2);
+
+		$query3='insert into vtiger_seattachmentsrel values(?,?)';
+		$adb->pquery($query3, array($id, $current_id));
+
+		return true;
+	}
+	else
+	{
+		$log->debug("pdf not attached");
+		return false;
+	}
+}
+
+
 ?>
