@@ -7,7 +7,7 @@
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
 *
- ********************************************************************************/
+********************************************************************************/
 ?>
 <html>
 <body>
@@ -32,6 +32,11 @@ else if(document.all)
 require_once('include/database/PearDatabase.php');
 require_once('config.php');
 
+global $default_charset;
+
+// Fix For: http://trac.vtiger.com/cgi-bin/trac.cgi/ticket/2107
+$randomfilename = "vt_" . str_replace(array("."," "), "", microtime());
+
 $templateid = $_REQUEST['mergefile'];
 if($templateid == "")
 {
@@ -39,23 +44,27 @@ if($templateid == "")
 }
 //get the particular file from db and store it in the local hard disk.
 //store the path to the location where the file is stored and pass it  as parameter to the method 
-$sql = "select filename,data,filesize from vtiger_wordtemplates where templateid=".$templateid;
+$sql = "select filename,data,filesize from vtiger_wordtemplates where templateid=?";
 
-$result = $adb->query($sql);
+$result = $adb->pquery($sql, array($templateid));
 $temparray = $adb->fetch_array($result);
 
 $fileContent = $temparray['data'];
-$filename=$temparray['filename'];
+$filename=html_entity_decode($temparray['filename'], ENT_QUOTES, $default_charset);
+
+// Fix For: http://trac.vtiger.com/cgi-bin/trac.cgi/ticket/2107
+$filename= $randomfilename . "_word.doc";
+
 $filesize=$temparray['filesize'];
 $wordtemplatedownloadpath =$root_directory ."/test/wordtemplatedownload/";
 
 
-$handle = fopen($wordtemplatedownloadpath .$temparray['filename'],"wb");
+$handle = fopen($wordtemplatedownloadpath .$filename,"wb");
 fwrite($handle,base64_decode($fileContent),$filesize);
 fclose($handle);
 
 //for mass merge
-$mass_merge = $_REQUEST['idlist'];
+$mass_merge = $_REQUEST['allselectedboxes'];
 $single_record = $_REQUEST['record'];
 
 if($mass_merge != "")
@@ -65,7 +74,7 @@ if($mass_merge != "")
 	$temp_mass_merge = $mass_merge;
 	if(array_pop($temp_mass_merge)=="")
 		array_pop($mass_merge);
-	$mass_merge = implode(",",$mass_merge);
+	//$mass_merge = implode(",",$mass_merge);
 }else if($single_record != "")
 {
 	$mass_merge = $single_record;	
@@ -81,17 +90,19 @@ require('user_privileges/user_privileges_'.$current_user->id.'.php');
 if($is_admin == true || $profileGlobalPermission[1] == 0 || $profileGlobalPermission[2] == 0 || $module == "Users" || $module == "Emails")
 {
 	$query1="select tablename,columnname,fieldlabel from vtiger_field where tabid=7 order by tablename";
+	$params1 = array();
 }
 else
 {
 	$profileList = getCurrentUserProfileList();
-	$query1="select vtiger_field.tablename,vtiger_field.columnname,vtiger_field.fieldlabel from vtiger_field INNER JOIN vtiger_profile2field ON vtiger_profile2field.fieldid=vtiger_field.fieldid INNER JOIN vtiger_def_org_field ON vtiger_def_org_field.fieldid=vtiger_field.fieldid where vtiger_field.tabid in (7) AND vtiger_profile2field.visible=0 AND vtiger_def_org_field.visible=0 AND vtiger_profile2field.profileid IN ".$profileList." GROUP BY vtiger_field.fieldid order by vtiger_field.tablename";
+	$query1="select vtiger_field.tablename,vtiger_field.columnname,vtiger_field.fieldlabel from vtiger_field INNER JOIN vtiger_profile2field ON vtiger_profile2field.fieldid=vtiger_field.fieldid INNER JOIN vtiger_def_org_field ON vtiger_def_org_field.fieldid=vtiger_field.fieldid where vtiger_field.tabid in (7) AND vtiger_profile2field.visible=0 AND vtiger_def_org_field.visible=0 AND vtiger_profile2field.profileid IN (". generateQuestionMarks($profileList) .") GROUP BY vtiger_field.fieldid order by vtiger_field.tablename";
+	$params1 = array($profileList);
 	//Postgres 8 fixes
 	if( $adb->dbType == "pgsql")
-	$sql = fixPostgresQuery( $sql, $log, 0);
+		$query1 = fixPostgresQuery( $query1, $log, 0);
 }
 
-$result = $adb->query($query1);
+$result = $adb->pquery($query1, $params1);
 $y=$adb->num_rows($result);
 	
 for ($x=0; $x<$y; $x++)
@@ -126,21 +137,30 @@ $query = "select ".$selectcolumns." from vtiger_leaddetails
   LEFT JOIN vtiger_groups
   	ON vtiger_groups.groupname = vtiger_leadgrouprelation.groupname
   left join vtiger_users on vtiger_users.id = vtiger_crmentity.smownerid
-  where vtiger_crmentity.deleted=0 and vtiger_leaddetails.leadid in (".$mass_merge.")";
+  where vtiger_crmentity.deleted=0 and vtiger_leaddetails.leadid in (". generateQuestionMarks($mass_merge) .")";
 		
-$result = $adb->query($query);
-	
+$result = $adb->pquery($query, array($mass_merge));
+$avail_pick_arr = getAccessPickListValues('Leads');	
 while($columnValues = $adb->fetch_array($result))
 {
-	$y=$adb->num_fields($result);
+  $y=$adb->num_fields($result);
   for($x=0; $x<$y; $x++)
   {
-		$value = $columnValues[$x];
+	  $value = $columnValues[$x];
+	 foreach($columnValues as $key=>$val)
+	 {
+		if($val == $value && $value != '')
+		{
+		  if(array_key_exists($key,$avail_pick_arr))
+		  {
+			if(!in_array($val,$avail_pick_arr[$key]))
+			{
+				$value = "Not Accessible";
+			}
+		  }
+		}
+	 }
   	//<<<<<<<<<<<<<<< For Blank Fields >>>>>>>>>>>>>>>>>>>>>>>>>>>>
-	if($value == "0")
-  	{
-  		$value = "";
-  	}
   	if(trim($value) == "--None--" || trim($value) == "--none--")
   	{
   		$value = "";
@@ -153,7 +173,7 @@ while($columnValues = $adb->fetch_array($result))
 		{
 			$actual_values[$x] = '"'.$actual_values[$x].'"';
 		}
-		$actual_values[$x] = str_replace(","," ",$actual_values[$x]);
+		$actual_values[$x] = decode_html(str_replace(","," ",$actual_values[$x]));
   }
 	$mergevalue[] = implode($actual_values,",");  	
 }
@@ -162,8 +182,10 @@ $csvdata = implode($mergevalue,"###");
 {
 	die("No vtiger_fields to do Merge");
 }	
+// Fix for: http://trac.vtiger.com/cgi-bin/trac.cgi/ticket/2107
+$datafilename = $randomfilename . "_data.csv";
 
-$handle = fopen($wordtemplatedownloadpath."datasrc.csv","wb");
+$handle = fopen($wordtemplatedownloadpath.$datafilename,"wb");
 fwrite($handle,$csvheader."\r\n");
 fwrite($handle,str_replace("###","\r\n",$csvdata));
 fclose($handle);
@@ -187,7 +209,7 @@ if (window.ActiveXObject){
         				if(objMMPage.Init())
         				{
         					objMMPage.vLTemplateDoc();
-        					objMMPage.bBulkHDSrc("<?php echo $site_URL;?>/test/wordtemplatedownload/datasrc.csv");
+							objMMPage.bBulkHDSrc("<?php echo $site_URL;?>/test/wordtemplatedownload/<?php echo $datafilename ?>");
         					objMMPage.vBulkOpenDoc();
         					objMMPage.UnInit()
         					window.history.back();
