@@ -17,8 +17,10 @@ $versions = Array(
 			"501"=>"5.0.1",
 			"502"=>"5.0.2",
 			"503rc2"=>"5.0.3 RC2",
+			"503"=>"5.0.3",
+			"504rc"=>"5.0.4 RC",
 		 );
 
-$current_version = '503';
+$current_version = '504';
 
 ?>
