@@ -25,6 +25,7 @@ global $related_modules;
 $adv_filter_options = array("e"=>"equals",
 		            "n"=>"not equal to",
 			    "s"=>"starts with",
+			    "ew"=>"ends with",
 			    "c"=>"contains",
 			    "k"=>"does not contain",
 			    "l"=>"less than",
@@ -134,16 +135,16 @@ class Reports extends CRMEntity{
 		if($reportid != "")
 		{
 			$ssql = "select vtiger_reportmodules.*,vtiger_report.* from vtiger_report inner join vtiger_reportmodules on vtiger_report.reportid = vtiger_reportmodules.reportmodulesid";
-			$ssql .= " where vtiger_report.reportid =".$reportid;
-			$result = $adb->query($ssql);
+			$ssql .= " where vtiger_report.reportid = ?";
+			$result = $adb->pquery($ssql, array($reportid));
 			$reportmodulesrow = $adb->fetch_array($result);
 			if($reportmodulesrow)
 			{
 				$this->primodule = $reportmodulesrow["primarymodule"];
 				$this->secmodule = $reportmodulesrow["secondarymodules"];
 				$this->reporttype = $reportmodulesrow["reporttype"];
-				$this->reportname = $reportmodulesrow["reportname"];
-				$this->reportdescription = $reportmodulesrow["description"];
+				$this->reportname = decode_html($reportmodulesrow["reportname"]);
+				$this->reportdescription = decode_html($reportmodulesrow["description"]);
 				$this->folderid = $reportmodulesrow["folderid"];
 			}
 		}
@@ -162,7 +163,7 @@ class Reports extends CRMEntity{
 		global $adb,$log,$mod_strings;
 		$returndata = Array();
 		$sql = "select * from vtiger_reportfolder order by folderid";
-		$result = $adb->query($sql);
+		$result = $adb->pquery($sql, array());
 		$reportfldrow = $adb->fetch_array($result);
 		if($mode != '')
 		{
@@ -175,6 +176,8 @@ class Reports extends CRMEntity{
 					$details['id'] = $reportfldrow["folderid"]; 
 					$details['name'] = ($mod_strings[$reportfldrow["foldername"]] == '' ) ? $reportfldrow["foldername"]:$mod_strings[$reportfldrow["foldername"]]; 
 					$details['description'] = $reportfldrow["description"]; 
+					$details['fname'] = popup_decode_html($details['name']);
+					$details['fdescription'] = popup_decode_html($reportfldrow["description"]);
 					$details['details'] = $this->sgetRptsforFldr($reportfldrow["folderid"]);
 					$returndata[] = $details;
 				}
@@ -188,6 +191,8 @@ class Reports extends CRMEntity{
 				$details['id'] = $reportfldrow["folderid"]; 
 				$details['name'] = ($mod_strings[$reportfldrow["foldername"]] == '' ) ? $reportfldrow["foldername"]:$mod_strings[$reportfldrow["foldername"]]; 
 				$details['description'] = $reportfldrow["description"]; 
+				$details['fname'] = popup_decode_html($details['name']);
+				$details['fdescription'] = popup_decode_html($reportfldrow["description"]);
 				$returndata[] = $details;
 			}while($reportfldrow = $adb->fetch_array($result));
 		}
@@ -213,8 +218,8 @@ class Reports extends CRMEntity{
 		require_once('include/utils/UserInfoUtil.php');
 
 		$sql = "select vtiger_report.*, vtiger_reportmodules.* from vtiger_report inner join vtiger_reportfolder on vtiger_reportfolder.folderid = vtiger_report.folderid";
-		$sql .= " inner join vtiger_reportmodules on vtiger_reportmodules.reportmodulesid = vtiger_report.reportid where vtiger_reportfolder.folderid=".$rpt_fldr_id;
-		$result = $adb->query($sql);
+		$sql .= " inner join vtiger_reportmodules on vtiger_reportmodules.reportmodulesid = vtiger_report.reportid where vtiger_reportfolder.folderid=?";
+		$result = $adb->pquery($sql, array($rpt_fldr_id));
 		$report = $adb->fetch_array($result);
 		if(count($report)>0)
 		{
@@ -304,30 +309,46 @@ class Reports extends CRMEntity{
 		global $log;
 		global $current_user;
 
+		if(is_string($block)) $block = explode(",", $block);
 
 		$tabid = getTabid($module);
-
+		$params = array($tabid, $block);
 		
 		require('user_privileges/user_privileges_'.$current_user->id.'.php');
 		//Security Check 
 		if($is_admin == true || $profileGlobalPermission[1] == 0 || $profileGlobalPermission[2] ==0)
 		{
-			$sql = "select * from vtiger_field where vtiger_field.tabid=".$tabid." and vtiger_field.block in (".$block .") and vtiger_field.displaytype in (1,2,3) order by sequence";
+			$sql = "select * from vtiger_field where vtiger_field.tabid=? and vtiger_field.block in (". generateQuestionMarks($block) .") and vtiger_field.displaytype in (1,2,3) ";
+
+			//fix for Ticket #4016
+			if($module == "Calendar")
+				$sql.=" group by vtiger_field.fieldlabel order by sequence";
+			else
+				$sql.=" order by sequence";
 		}
 		else
 		{
 			
 			$profileList = getCurrentUserProfileList();
-			$sql = "select * from vtiger_field inner join vtiger_profile2field on vtiger_profile2field.fieldid=vtiger_field.fieldid inner join vtiger_def_org_field on vtiger_def_org_field.fieldid=vtiger_field.fieldid where vtiger_field.tabid=".$tabid." and vtiger_field.block in (".$block .") and vtiger_field.displaytype in (1,2,3) and vtiger_profile2field.visible=0 and vtiger_def_org_field.visible=0 and vtiger_profile2field.profileid in ".$profileList." group by vtiger_field.fieldid order by sequence";
+			$sql = "select * from vtiger_field inner join vtiger_profile2field on vtiger_profile2field.fieldid=vtiger_field.fieldid inner join vtiger_def_org_field on vtiger_def_org_field.fieldid=vtiger_field.fieldid where vtiger_field.tabid=? and vtiger_field.block in (". generateQuestionMarks($block) .") and vtiger_field.displaytype in (1,2,3) and vtiger_profile2field.visible=0 and vtiger_def_org_field.visible=0";
+			if (count($profileList) > 0) {
+				$sql .= " and vtiger_profile2field.profileid in (". generateQuestionMarks($profileList) .")";	
+				array_push($params, $profileList);
+			}
+
+			//fix for Ticket #4016
+			if($module == "Calendar")
+				$sql.=" group by vtiger_field.fieldid,vtiger_field.fieldlabel order by sequence";
+			else
+				$sql.=" group by vtiger_field.fieldid order by sequence";			
 		}
 		
 		if($module == 'HelpDesk' && $block == 25)
-                {
-                        $module_columnlist['vtiger_crmentity:crmid:HelpDesk_Ticket_ID:ticketid:I'] = 'Ticket ID';
-                }
-
-
-		$result = $adb->query($sql);
+        {
+        		$module_columnlist['vtiger_crmentity:crmid:HelpDesk_Ticket_ID:ticketid:I'] = 'Ticket ID';
+        }
+		
+		$result = $adb->pquery($sql, $params);
 		$noofrows = $adb->num_rows($result);
 		for($i=0; $i<$noofrows; $i++)
 		{
@@ -338,6 +359,10 @@ class Reports extends CRMEntity{
 			$uitype = $adb->query_result($result,$i,"uitype");
 			$fieldtype = explode("~",$fieldtype);
 			$fieldtypeofdata = $fieldtype[0];
+
+			//Here we Changing the displaytype of the field. So that its criteria will be displayed correctly in Reports Advance Filter.
+			$fieldtypeofdata=ChangeTypeOfData_Filter($fieldtablename,$fieldcolname,$fieldtypeofdata);
+			
 			if($uitype == 68 || $uitype == 59)
 			{
 				$fieldtypeofdata = 'V';
@@ -391,6 +416,16 @@ class Reports extends CRMEntity{
 				$fieldtablename = "vtiger_productsRel";
 				$fieldcolname = "productname";
 			}
+			if($fieldname == 'product_id' && $fieldtablename == 'vtiger_campaign') 
+			{
+				$fieldtablename = "vtiger_productsCampaigns";
+				$fieldcolname = "productname";
+			}
+			if($fieldname == 'campaignid')
+			{
+				$fieldtablename = "vtiger_campaign";
+				$fieldcolname = "campaignname";
+			}
 
 			$fieldlabel = $adb->query_result($result,$i,"fieldlabel");
 			$fieldlabel1 = str_replace(" ","_",$fieldlabel);
@@ -412,9 +447,8 @@ class Reports extends CRMEntity{
 	function getSelectedStandardCriteria($reportid)
 	{
 		global $adb;
-		$sSQL = "select vtiger_reportdatefilter.* from vtiger_reportdatefilter inner join vtiger_report on vtiger_report.reportid = vtiger_reportdatefilter.datefilterid where vtiger_report.reportid=".$reportid;
-
-		$result = $adb->query($sSQL);
+		$sSQL = "select vtiger_reportdatefilter.* from vtiger_reportdatefilter inner join vtiger_report on vtiger_report.reportid = vtiger_reportdatefilter.datefilterid where vtiger_report.reportid=?";
+		$result = $adb->pquery($sSQL, array($reportid));
 		$selectedstdfilter = $adb->fetch_array($result);
 
 		$this->stdselectedcolumn = $selectedstdfilter["datecolumnname"];
@@ -488,20 +522,24 @@ class Reports extends CRMEntity{
 		}	
 		$blockids = implode(",",$blockids);	
 
+		$params = array($tabid, $blockids);
 		if($is_admin == true || $profileGlobalPermission[1] == 0 || $profileGlobalPermission[2] == 0)
 		{
 			//uitype 6 and 23 added for start_date,EndDate,Expected Close Date
-			$sql = "select * from vtiger_field where vtiger_field.tabid=".$tabid." and (vtiger_field.uitype =5 or vtiger_field.uitype = 6 or vtiger_field.uitype = 23 or vtiger_field.displaytype=2) and vtiger_field.block in (".$blockids.") order by vtiger_field.sequence";
+			$sql = "select * from vtiger_field where vtiger_field.tabid=? and (vtiger_field.uitype =5 or vtiger_field.uitype = 6 or vtiger_field.uitype = 23 or vtiger_field.displaytype=2) and vtiger_field.block in (". generateQuestionMarks($block) .") order by vtiger_field.sequence";
 		}
 		else
 		{
-
 			$profileList = getCurrentUserProfileList();
-			$sql = "select * from vtiger_field inner join vtiger_tab on vtiger_tab.tabid = vtiger_field.tabid inner join vtiger_profile2field on vtiger_profile2field.fieldid=vtiger_field.fieldid inner join vtiger_def_org_field on vtiger_def_org_field.fieldid=vtiger_field.fieldid  where vtiger_field.tabid=".$tabid." and (vtiger_field.uitype =5 or vtiger_field.displaytype=2) and vtiger_profile2field.visible=0 and vtiger_def_org_field.visible=0 and vtiger_field.block in (".$blockids.") and vtiger_profile2field.profileid in ".$profileList." order by vtiger_field.sequence";
-
+			$sql = "select * from vtiger_field inner join vtiger_tab on vtiger_tab.tabid = vtiger_field.tabid inner join vtiger_profile2field on vtiger_profile2field.fieldid=vtiger_field.fieldid inner join vtiger_def_org_field on vtiger_def_org_field.fieldid=vtiger_field.fieldid  where vtiger_field.tabid=? and (vtiger_field.uitype =5 or vtiger_field.displaytype=2) and vtiger_profile2field.visible=0 and vtiger_def_org_field.visible=0 and vtiger_field.block in (". generateQuestionMarks($block) .")";
+			if (count($profileList) > 0) {
+				$sql .= " and vtiger_profile2field.profileid in (". generateQuestionMarks($profileList) .")";
+				array_push($params, $profileList);
+			}
+			$sql .= " order by vtiger_field.sequence";
 		}
 
-		$result = $adb->query($sql);
+		$result = $adb->pquery($sql, $params);
 
 		while($criteriatyperow = $adb->fetch_array($result))
 		{
@@ -813,16 +851,27 @@ function getEscapedColumns($selectedfields)
 		
 		$profileList = getCurrentUserProfileList();
 		$query = "select vtiger_field.fieldname from vtiger_field inner join vtiger_profile2field on vtiger_profile2field.fieldid=vtiger_field.fieldid inner join vtiger_def_org_field on vtiger_def_org_field.fieldid=vtiger_field.fieldid where";
+		$params = array();
 		if($module == "Calendar")
 		{
-			$query .= " vtiger_field.tabid in (9,16) and vtiger_field.displaytype in (1,2,3) and vtiger_profile2field.visible=0 and vtiger_def_org_field.visible=0 and vtiger_profile2field.profileid in ".$profileList." group by vtiger_field.fieldid order by block,sequence";
+			$query .= " vtiger_field.tabid in (9,16) and vtiger_field.displaytype in (1,2,3) and vtiger_profile2field.visible=0 and vtiger_def_org_field.visible=0";
+			if (count($profileList) > 0) {				
+				$query .= " and vtiger_profile2field.profileid in (". generateQuestionMarks($profileList) .")";
+				array_push($params, $profileList);
+			}
+			$query .= " group by vtiger_field.fieldid order by block,sequence";
 		}
 		else
 		{
-			$query .= " vtiger_field.tabid in (select tabid from vtiger_tab where vtiger_tab.name in ('".$this->primodule."','".$this->secmodule."')) and vtiger_field.displaytype in (1,2,3) and vtiger_profile2field.visible=0 and vtiger_def_org_field.visible=0 and vtiger_profile2field.profileid in ".$profileList." group by vtiger_field.fieldid order by block,sequence";
+			array_push($params, $this->primodule, $this->secmodule);
+			$query .= " vtiger_field.tabid in (select tabid from vtiger_tab where vtiger_tab.name in (?,?)) and vtiger_field.displaytype in (1,2,3) and vtiger_profile2field.visible=0 and vtiger_def_org_field.visible=0";
+			if (count($profileList) > 0) {				
+				$query .= " and vtiger_profile2field.profileid in (". generateQuestionMarks($profileList) .")";
+				array_push($params, $profileList);
+			}
+			$query .= " group by vtiger_field.fieldid order by block,sequence";
 		}
-
-		$result = $adb->query($query);
+		$result = $adb->pquery($query, $params);
 
 		
 		while($collistrow = $adb->fetch_array($result))
@@ -848,9 +897,9 @@ function getEscapedColumns($selectedfields)
 
 		$sreportsortsql = "select vtiger_reportsortcol.* from vtiger_report";
 		$sreportsortsql .= " inner join vtiger_reportsortcol on vtiger_report.reportid = vtiger_reportsortcol.reportid";
-		$sreportsortsql .= " where vtiger_report.reportid =".$reportid." order by vtiger_reportsortcol.sortcolid";
+		$sreportsortsql .= " where vtiger_report.reportid =? order by vtiger_reportsortcol.sortcolid";
 
-		$result = $adb->query($sreportsortsql);
+		$result = $adb->pquery($sreportsortsql, array($reportid));
 		$noofrows = $adb->num_rows($result);
 
 		for($i=0; $i<$noofrows; $i++)
@@ -879,9 +928,9 @@ function getEscapedColumns($selectedfields)
 
 		$ssql = "select vtiger_selectcolumn.* from vtiger_report inner join vtiger_selectquery on vtiger_selectquery.queryid = vtiger_report.queryid";
 		$ssql .= " left join vtiger_selectcolumn on vtiger_selectcolumn.queryid = vtiger_selectquery.queryid";
-		$ssql .= " where vtiger_report.reportid =".$reportid;
+		$ssql .= " where vtiger_report.reportid = ?";
 		$ssql .= " order by vtiger_selectcolumn.columnindex";
-		$result = $adb->query($ssql);
+		$result = $adb->pquery($ssql, array($reportid));
 		$permitted_fields = Array();
 
 		while($columnslistrow = $adb->fetch_array($result))
@@ -890,39 +939,29 @@ function getEscapedColumns($selectedfields)
 			$fieldcolname = $columnslistrow["columnname"];
 			list($tablename,$colname,$module_field,$fieldname,$single) = split(":",$fieldcolname);
 			require('user_privileges/user_privileges_'.$current_user->id.'.php');
+			list($module,$field) = split("_",$module_field);
 			if(sizeof($permitted_fields) == 0 && $is_admin == false && $profileGlobalPermission[1] == 1 && $profileGlobalPermission[2] == 1)
 			{
-				list($module,$field) = split("_",$module_field);
 				$permitted_fields = $this->getaccesfield($module);	
 			}
-			$selectedfields = explode(":",$fieldcolname);
 			$querycolumns = $this->getEscapedColumns($selectedfields);
-
-				$mod_strings = return_module_language($current_language,$module);
-				$fieldlabel = trim(str_replace($module," ",$selectedfields[2]));
-				$fieldlabel = trim(str_replace("_"," ",$fieldlabel));		
-			if(sizeof($permitted_fields) != 0 && !in_array($fieldname,$permitted_fields) && $fieldname != 'ticketid')
+			$fieldlabel = trim(str_replace($module," ",$module_field));
+			$mod_arr=explode('_',$fieldlabel);
+                        $mod = ($mod_arr[0] == '')?$module:$mod_arr[0];
+			$fieldlabel = trim(str_replace("_"," ",$fieldlabel));
+			//modified code to support i18n issue 
+			$mod_lbl = getTranslatedString($mod,$module); //module
+			$fld_lbl = getTranslatedString($fieldlabel,$module); //fieldlabel
+			$fieldlabel = $mod_lbl." ".$fld_lbl;
+			if(CheckFieldPermission($fieldname,$mod) != 'true')
 			{
-				if(isset($mod_strings[$fieldlabel])) 
-				{
-					$shtml .= "<option permission='no' value=\"".$fieldcolname."\" disabled = 'true'>".$mod_strings[$fieldlabel]."</option>";
-				}
-				else 
-				{
 					$shtml .= "<option permission='no' value=\"".$fieldcolname."\" disabled = 'true'>".$fieldlabel."</option>";
-				}
 			}
 			else
 			{
-				if(isset($mod_strings[$fieldlabel])) 
-				{
-					$shtml .= "<option permission='yes' value=\"".$fieldcolname."\">".$mod_strings[$fieldlabel]."</option>";
-				}
-			    	else 
-				{
 					$shtml .= "<option permission='yes' value=\"".$fieldcolname."\">".$fieldlabel."</option>";
-				}
 			}
+			//end
 		}
 		$log->info("ReportRun :: Successfully returned getQueryColumnsList".$reportid);
 		return $shtml;		
@@ -933,17 +972,37 @@ function getEscapedColumns($selectedfields)
 		global $modules;
 		global $log;
 		$ssql = 'select vtiger_relcriteria.* from vtiger_report inner join vtiger_relcriteria on vtiger_relcriteria.queryid = vtiger_report.queryid left join vtiger_selectquery on vtiger_relcriteria.queryid = vtiger_selectquery.queryid';
-		$ssql.= " where vtiger_report.reportid =".$reportid." order by vtiger_relcriteria.columnindex";
+		$ssql.= " where vtiger_report.reportid = ? order by vtiger_relcriteria.columnindex";
 
-		$result = $adb->query($ssql);
+		$result = $adb->pquery($ssql, array($reportid));
 
 		while($relcriteriarow = $adb->fetch_array($result))
 		{
 			$this->advft_column[] = $relcriteriarow["columnname"];
 			$this->advft_option[] = $relcriteriarow["comparator"];
-			$this->advft_value[] = $relcriteriarow["value"];
-		}
+			$advfilterval = $relcriteriarow["value"];
+			$col = explode(":",$relcriteriarow["columnname"]);
+			$temp_val = explode(",",$relcriteriarow["value"]);
+			if($col[4] == 'D' || ($col[4] == 'T' && $col[1] != 'time_start' && $col[1] != 'time_end') || ($col[4] == 'DT')) 
+			{
+					$val = Array();
+					for($x=0;$x<count($temp_val);$x++)
+					{
+						list($temp_date,$temp_time) = explode(" ",$temp_val[$x]);
+						$temp_date = getDisplayDate(trim($temp_date));
+						if(trim($temp_time) != '')
+							$temp_date .= ' '.$temp_time;
+						$val[$x]=$temp_date;
+						if($x == 0)
+							$advfilterval = $val[$x];
+						else
+							$advfilterval = ','.$val[$x];
+					}
 
+			}
+
+			$this->advft_value[] = $advfilterval;
+		}
 		$log->info("Reports :: Successfully returned getAdvancedFilterList");
 		return true;
 	}
@@ -961,7 +1020,7 @@ function getEscapedColumns($selectedfields)
 		global $log;
 
 		$sql = "select * from vtiger_reportfolder order by folderid";
-		$result = $adb->query($sql);
+		$result = $adb->pquery($sql, array());
 		$reportfldrow = $adb->fetch_array($result);
 		$x = 0;
 		do
@@ -1008,8 +1067,8 @@ function getEscapedColumns($selectedfields)
 		$options = Array();
 		if($reportid != "")
 		{
-			$ssql = "select vtiger_reportsummary.* from vtiger_reportsummary inner join vtiger_report on vtiger_report.reportid = vtiger_reportsummary.reportsummaryid where vtiger_report.reportid=".$reportid;
-			$result = $adb->query($ssql);
+			$ssql = "select vtiger_reportsummary.* from vtiger_reportsummary inner join vtiger_report on vtiger_report.reportid = vtiger_reportsummary.reportsummaryid where vtiger_report.reportid=?";
+			$result = $adb->pquery($ssql, array($reportid));
 			if($result)
 			{
 				$reportsummaryrow = $adb->fetch_array($result);
@@ -1052,15 +1111,19 @@ function getEscapedColumns($selectedfields)
 		require('user_privileges/user_privileges_'.$current_user->id.'.php');
 		$tabid = getTabid($module);
 		$escapedchars = Array('_SUM','_AVG','_MIN','_MAX');
+		$sparams = array($tabid);
 		if($is_admin == true || $profileGlobalPermission[1] == 0 || $profileGlobalPermission[2] ==0)
 		{
-			$ssql = "select * from vtiger_field inner join vtiger_tab on vtiger_tab.tabid = vtiger_field.tabid where vtiger_field.uitype != 50 and vtiger_field.tabid=".$tabid." and vtiger_field.displaytype = 1 ";
-		
+			$ssql = "select * from vtiger_field inner join vtiger_tab on vtiger_tab.tabid = vtiger_field.tabid where vtiger_field.uitype != 50 and vtiger_field.tabid=? and vtiger_field.displaytype in (1,2,3) ";		
 		}
 		else
 		{
 			$profileList = getCurrentUserProfileList();
-			$ssql = "select * from vtiger_field inner join vtiger_tab on vtiger_tab.tabid = vtiger_field.tabid inner join vtiger_def_org_field on vtiger_def_org_field.fieldid=vtiger_field.fieldid inner join vtiger_profile2field on vtiger_profile2field.fieldid=vtiger_field.fieldid  where vtiger_field.uitype != 50 and vtiger_field.tabid=".$tabid." and vtiger_field.displaytype = 1 and vtiger_def_org_field.visible=0 and vtiger_profile2field.visible=0 and vtiger_profile2field.profileid in ".$profileList;
+			$ssql = "select * from vtiger_field inner join vtiger_tab on vtiger_tab.tabid = vtiger_field.tabid inner join vtiger_def_org_field on vtiger_def_org_field.fieldid=vtiger_field.fieldid inner join vtiger_profile2field on vtiger_profile2field.fieldid=vtiger_field.fieldid  where vtiger_field.uitype != 50 and vtiger_field.tabid=? and vtiger_field.displaytype in (1,2,3) and vtiger_def_org_field.visible=0 and vtiger_profile2field.visible=0";
+			if (count($profileList) > 0) {
+				$ssql .= " and vtiger_profile2field.profileid in (". generateQuestionMarks($profileList) .")";
+				array_push($sparams, $profileList);
+			}
 		}
 
 		//Added to avoid display the Related fields (Account name,Vandor name,product name, etc) in Report Calculations(SUM,AVG..)			
@@ -1068,44 +1131,44 @@ function getEscapedColumns($selectedfields)
 		{
 			case 2://Potentials
 				//ie. Campaign name will not displayed in Potential's report calcullation
-				$ssql.= "and vtiger_field.fieldname not in ('campaignid') ";
+				$ssql.= " and vtiger_field.fieldname not in ('campaignid')";
 				break;
 			case 4://Contacts
-				$ssql.= "and vtiger_field.fieldname not in ('account_id') ";
+				$ssql.= " and vtiger_field.fieldname not in ('account_id')";
 				break;
 			case 6://Accounts
-				$ssql.= "and vtiger_field.fieldname not in ('account_id') ";
+				$ssql.= " and vtiger_field.fieldname not in ('account_id')";
 				break;
 			case 9://Calandar
-				$ssql.= "and vtiger_field.fieldname not in ('parent_id','contact_id') ";
+				$ssql.= " and vtiger_field.fieldname not in ('parent_id','contact_id')";
 				break;
 			case 13://Trouble tickets(HelpDesk)
-				$ssql.= "and vtiger_field.fieldname not in ('parent_id','product_id') ";
+				$ssql.= " and vtiger_field.fieldname not in ('parent_id','product_id')";
 				break;
 			case 14://Products
-				$ssql.= "and vtiger_field.fieldname not in ('vendor_id') ";
+				$ssql.= " and vtiger_field.fieldname not in ('vendor_id')";
 				break;
 			case 20://Quotes
-				$ssql.= "and vtiger_field.fieldname not in ('potential_id','assigned_user_id1','account_id') ";
+				$ssql.= " and vtiger_field.fieldname not in ('potential_id','assigned_user_id1','account_id')";
 				break;
 			case 21://Purchase Order
-				$ssql.= "and vtiger_field.fieldname not in ('contact_id','vendor_id') ";
+				$ssql.= " and vtiger_field.fieldname not in ('contact_id','vendor_id')";
 				break;
 			case 22://SalesOrder
-				$ssql.= "and vtiger_field.fieldname not in ('potential_id','account_id','contact_id','quote_id') ";
+				$ssql.= " and vtiger_field.fieldname not in ('potential_id','account_id','contact_id','quote_id')";
 				break;
 			case 23://Invoice
-				$ssql.= "and vtiger_field.fieldname not in ('salesorder_id','contact_id','account_id') ";
+				$ssql.= " and vtiger_field.fieldname not in ('salesorder_id','contact_id','account_id')";
 				break;
 			case 26://Campaings
-				$ssql.= "and vtiger_field.fieldname not in ('product_id') ";
+				$ssql.= " and vtiger_field.fieldname not in ('product_id')";
 				break;
 
 		}
 
-		$ssql.= "order by sequence";
+		$ssql.= " order by sequence";
 
-		$result = $adb->query($ssql);
+		$result = $adb->pquery($ssql, $sparams);
 		$columntototalrow = $adb->fetch_array($result);
 		$options_list = Array();	
 		do
@@ -1135,6 +1198,10 @@ function getEscapedColumns($selectedfields)
 						}
 
 					}
+					if(isset($_REQUEST["record"]) && $_REQUEST["record"] != '')
+					{
+						$options['label'][] = getTranslatedString($columntototalrow['tablabel']).' -'.getTranslatedString($columntototalrow['fieldlabel']);
+					}	
 
 					$columntototalrow['fieldlabel'] = str_replace(" ","_",$columntototalrow['fieldlabel']);
 					$options []= getTranslatedString($columntototalrow['tablabel']).' - '.getTranslatedString($columntototalrow['fieldlabel']);
