@@ -216,7 +216,6 @@ $mod_strings = Array(
 'LBL_MEMBER'=>'Members',
 'LBL_MEMBER_AVLBL'=>'Available Entities & Members',
 'LBL_MEMBER_SELECTED'=>'Selected Members',
-'LBL_DESCRIPTION'=>'Description',
 'LBL_GROUP_MESG1'=>'Groups are a flexible way to assign access rights, when complex access rights has to be defined. You can combine multiple entities like Roles, Users, profiles etc into a single group.',
 'LBL_GROUP_MESG2'=>'To add, select the Entity members from left and click the ">>" button.',
 'LBL_GROUP_MESG3'=>'To remove, select the group members from the right and click the "<<" button.',
@@ -642,7 +641,6 @@ $mod_strings = Array(
 'LBL_4_MIN'=>'4 minutes',
 'LBL_5_MIN'=>'5 minutes',
 'LBL_EMAILS_PER_PAGE'=>'Email per Page',
-
 // Added for 5.0.3
 
 'LBL_ENTER_PROFILE'=>'Enter The Profile Name',
@@ -653,6 +651,20 @@ $mod_strings = Array(
 'LBL_NOTIFICATION_ACTIVITY'=>'Notification Activity',
 'LBL_NOTIFICATION_EMAIL_INFO'=>'Notification Email Information',
 'LBL_GOTO_LISTVIEW_BUTTON'=>'Goto ListView',
+
+// Added/Updated for vtiger CRM 5.0.4
+
+'LBL_SSL' => 'SSL',
+//Added to fix the issue #4081
+'LBL_USERNAME_EXIST' => 'User Name Already Exists!',
+'LBL_UNAUTHORIZED_ACCESS' => 'Unauthorized access to user administration',
+//Added to provide User based TagCloud
+'LBL_TAGCLOUD_DISPLAY'=>'Tag Cloud Display',
+'INTERNAL_MAIL_COMPOSER'=>'Internal Mail Composer',
+
+// Added for 5.0.4 to Support Email notication on User Creation
+'User Login Details'=>'User Login Details',
+'LBL_TO_LOGIN' => 'to Login',
 );
 
 ?>
